@@ -43,42 +43,6 @@ pub fn cell_set_bg_alpha(cell: &mut NcCell, alpha: NcAlphaBits) {
     crate::channels_set_bg_alpha(&mut cell.channels, alpha);
 }
 
-// Channels --------------------------------------------------------------------
-
-/// Gets the foreground [NcChannel] from an [NcCell].
-///
-/// *Method: NcCell.[fchannel()][NcCell#method.fchannel].*
-#[inline]
-pub fn cell_fchannel(cell: &NcCell) -> NcChannel {
-    crate::channels_fchannel(cell.channels)
-}
-
-/// Gets the background [NcChannel] from an [NcCell].
-///
-/// *Method: NcCell.[bchannel()][NcCell#method.bchannel].*
-#[inline]
-pub fn cell_bchannel(cell: &NcCell) -> NcChannel {
-    crate::channels_bchannel(cell.channels)
-}
-
-/// Sets the foreground [NcChannel] of an [NcCell] and returns the new
-/// [NcChannelPair].
-///
-/// *Method: NcCell.[set_fchannel()][NcCell#method.set_fchannel].*
-#[inline]
-pub fn cell_set_fchannel(cell: &mut NcCell, channel: NcChannel) -> NcChannelPair {
-    crate::channels_set_fchannel(&mut cell.channels, channel)
-}
-
-/// Sets the background [NcChannel] of an [NcCell] and returns the new
-/// [NcChannelPair].
-///
-/// *Method: NcCell.[set_bchannel()][NcCell#method.set_bchannel].*
-#[inline]
-pub fn cell_set_bchannel(cell: &mut NcCell, channel: NcChannel) -> NcChannelPair {
-    crate::channels_set_bchannel(&mut cell.channels, channel)
-}
-
 // NcColor ---------------------------------------------------------------------
 
 /// Gets the foreground [NcColor] RGB components of an [NcCell],
@@ -315,9 +279,6 @@ pub fn cell_set_styles(cell: &mut NcCell, stylebits: NcStyleMask) {
 /// Does the [NcCell] contain an East Asian Wide codepoint?
 ///
 /// *Method: NcCell.[double_wide_p()][NcCell#method.double_wide_p].*
-//
-// REMAINDER: remove casting when fixed:
-// Waiting for: https://github.com/rust-lang/rust-bindgen/issues/1875
 #[inline]
 pub const fn cell_double_wide_p(cell: &NcCell) -> bool {
     cell.width > 0
@@ -339,38 +300,46 @@ pub const fn cell_wide_left_p(cell: &NcCell) -> bool {
     cell_double_wide_p(cell) && cell.gcluster != 0
 }
 
-/// Loads a 7-bit char into the [NcCell].
-///
-/// *Method: NcCell.[load_char()][NcCell#method.load_char].*
-//
-// NOTE: Unlike the original C function this doesn't return anything.
-// Waiting for: https://github.com/rust-lang/rust-bindgen/issues/1875
-#[inline]
-pub fn cell_load_char(plane: &mut NcPlane, cell: &mut NcCell, ch: NcEgc) /* -> i32 */
-{
-    unsafe {
-        crate::cell_release(plane, cell);
-    }
+// /// Loads a 7-bit [NcEgc] character into the [NcCell].
+// ///
+// /// *Method: NcCell.[load_char()][NcCell#method.load_char].*
+// //
+// // TODO:CHECK is this necessary at all?
+// #[inline]
+// pub fn cell_load_char(plane: &mut NcPlane, cell: &mut NcCell, ch: NcEgc) /* -> i32 */
+// {
+//     let _ = unsafe { crate::cell_load(plane, cell, ch) };
+// }
+// cell_load_char(struct ncplane* n, nccell* c, char ch){
+//   char gcluster[2];
+//   gcluster[0] = ch;
+//   gcluster[1] = '\0';
+//   let _ = cell_load(n, c, gcluster);
+// }
 
-    /* TODO new version:
-
-    char gcluster[2];
-    gcluster[0] = ch;
-    gcluster[1] = '\0';
-    return cell_load(n, c, gcluster);
-    */
-}
-
-// TODO:
-// // Load a UTF-8 encoded EGC of up to 4 bytes into the cell `c`.
-// static inline int
-// cell_load_egc32(struct ncplane* n, cell* c, uint32_t egc){
+// /// Loads a UTF-8 grapheme cluster of up to 4 bytes into the cell `c`.
+// ///
+// /// *Method: NcCell.[load_egc32()][NcCell#method.load_egc32].*
+// //
+// // TODO
+// #[inline]
+// pub fn cell_load_egc32(plane: &mut NcPlane, cell: &mut NcCell, egc: &str) -> NcIntResult {
 //     char gcluster[sizeof(egc) + 1];
 //     egc = egc.to_le();
 //     memcpy(gcluster, &egc, sizeof(egc));
 //     gcluster[4] = '\0';
 //     return cell_load(n, c, gcluster);
 // }
+// // Load a UTF-8 encoded EGC of up to 4 bytes into the nccell 'c'. Returns the
+// // number of bytes used, or -1 on error.
+// static inline int
+// cell_load_egc32(struct ncplane* n, nccell* c, uint32_t egc){
+//   char gcluster[sizeof(egc) + 1];
+//   egc = htole(egc);
+//   memcpy(gcluster, &egc, sizeof(egc));
+//   gcluster[4] = '\0';
+//   return cell_load(n, c, gcluster);
+// }
 
 /// Copies the UTF8-encoded [NcEgc] out of the [NcCell], whether simple or complex.
 ///
@@ -385,7 +354,7 @@ pub fn cell_strdup(plane: &NcPlane, cell: &NcCell) -> NcEgc {
     )
     .expect("wrong char")
 
-    // Unsafer option B (maybe faster, TODO: bench):
+    // Unsafer option B (maybe faster, TODO:BENCH):
     // unsafe {
     //     core::char::from_u32_unchecked(libc::strdup(cell_extended_gcluster(plane, cell)) as i32 as u32)
     // }
