@@ -91,7 +91,7 @@ pub use reimplemented::*;
 pub type NcChannel = u32;
 
 /// Extract these bits to get a channel's alpha value
-pub const NCCHANNEL_ALPHA_MASK: u32 = crate::bindings::ffi::CHANNEL_ALPHA_MASK;
+pub const NCCHANNEL_ALPHA_MASK: u32 = crate::bindings::ffi::CELL_BG_ALPHA_MASK;
 
 // NcAlphaBits
 //
@@ -191,7 +191,6 @@ pub type NcAlphaBits = u32;
 /// - [`NCCELL_FG_ALPHA_MASK`][crate::NCCELL_FG_ALPHA_MASK]
 /// - [`NCCELL_FG_PALETTE`][crate::NCCELL_FG_PALETTE]
 /// - [`NCCELL_FG_RGB_MASK`][crate::NCCELL_FG_RGB_MASK]
-/// - [`NCCELL_NOBACKGROUND_MASK`][crate::NCCELL_NOBACKGROUND_MASK]
 ///
 pub type NcChannelPair = u64;
 
@@ -224,15 +223,3 @@ pub type NcRgb = u32;
 /// `type in C: no data type`
 ///
 pub type NcColor = u8;
-
-/// the [NcEgc][crate::NcEgc] which form the various levels of a given geometry.
-///
-/// If the geometry is wide, things are arranged with the rightmost side
-/// increasing most quickly, i.e. it can be indexed as height arrays of
-/// 1 + height glyphs.
-/// i.e. The first five braille EGCs are all 0 on the left,
-/// [0..4] on the right.
-///
-/// `type in C: blitset (struct)`
-///
-pub type NcBlitSet = crate::bindings::ffi::blitset;
