@@ -3,6 +3,7 @@
 mod menu;
 mod multiselector;
 mod plot;
+mod progbar;
 mod reader;
 mod reel;
 mod selector;
@@ -10,6 +11,7 @@ mod selector;
 pub use menu::*;
 pub use multiselector::*;
 pub use plot::*;
+pub use progbar::*;
 pub use reader::*;
 pub use reel::*;
 pub use selector::*;
