@@ -1,6 +1,7 @@
 #include <pwd.h>
 #include <errno.h>
 #include <stdio.h>
+#include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
 #include <locale.h>
@@ -77,7 +78,7 @@ static distro_info distros[] = {
 
 static int
 fetch_bsd_cpuinfo(fetched_info* fi){
-#ifdef __linux__
+#if defined(__linux__) || defined(__gnu_hurd__)
   (void)fi;
 #else
   size_t len = sizeof(fi->core_count);
@@ -189,15 +190,20 @@ fetch_x_props(fetched_info* fi){
 // Returns NULL if no such file can be found. Return value is heap-allocated.
 static char *
 get_xdg_logo(const char *spec){
-  char logopath[PATH_MAX + 1]; // FIXME
-  int s = snprintf(logopath, sizeof(logopath) - 1, "%s/%s", "/usr/share/pixmaps/", spec);
-  if(s < 0 || (size_t)s >= sizeof(logopath)){
+  const char* logopath = "/usr/share/pixmaps/";
+  int dfd = open(logopath, O_CLOEXEC | O_DIRECTORY);
+  if(dfd < 0){
     return NULL;
   }
-  if(access(logopath, F_OK) == 0){
-    return strdup(logopath);
+  int r = faccessat(dfd, spec, R_OK, 0);
+  close(dfd);
+  if(r){
+    return NULL;
   }
-  return NULL;
+  char* p = malloc(strlen(spec) + strlen(logopath) + 1);
+  strcpy(p, logopath);
+  strcat(p, spec);
+  return p;
 }
 
 // FIXME deal more forgivingly with quotation marks
@@ -436,8 +442,8 @@ infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheigh
   char totalmet[BPREFIXSTRLEN + 1], usedmet[BPREFIXSTRLEN + 1];
   bprefix(sinfo.totalram, 1, totalmet, 1);
   bprefix(sinfo.totalram - sinfo.freeram, 1, usedmet, 1);
-  ncplane_printf_aligned(infop, 2, NCALIGN_LEFT, " RAM: %s/%s\n", usedmet, totalmet);
   ncplane_printf_aligned(infop, 2, NCALIGN_RIGHT, "Processes: %hu ", sinfo.procs);
+  ncplane_printf_aligned(infop, 2, NCALIGN_LEFT, " RAM: %sB/%sB", usedmet, totalmet);
 #endif
   ncplane_printf_aligned(infop, 3, NCALIGN_LEFT, " DM: %s", fi->desktop);
   ncplane_printf_aligned(infop, 3, NCALIGN_RIGHT, "Shell: %s ", fi->shell);
@@ -445,13 +451,13 @@ infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheigh
     ncplane_printf_aligned(infop, 4, NCALIGN_LEFT, " RGB TERM: %s", fi->term);
     nccell c = CELL_CHAR_INITIALIZER('R');
     cell_set_styles(&c, NCSTYLE_BOLD);
-    cell_set_fg_rgb8(&c, 0xd0, 0, 0);
+    cell_set_fg_rgb8(&c, 0xf0, 0xa0, 0xa0);
     ncplane_putc_yx(infop, 4, 1, &c);
     cell_load_char(infop, &c, 'G');
-    cell_set_fg_rgb8(&c, 0, 0xd0, 0);
+    cell_set_fg_rgb8(&c, 0xa0, 0xf0, 0xa0);
     ncplane_putc_yx(infop, 4, 2, &c);
     cell_load_char(infop, &c, 'B');
-    cell_set_fg_rgb8(&c, 0, 0, 0xd);
+    cell_set_fg_rgb8(&c, 0xa0, 0xa0, 0xf0);
     ncplane_putc_yx(infop, 4, 3, &c);
     cell_set_styles(&c, NCSTYLE_NONE);
   }else{
@@ -546,14 +552,14 @@ neologo_present(struct ncdirect* nc, const char* nlogo){
       maxlinelen = collen;
     }
   }
-  const int leftpad = (80 - maxlinelen) / 2;
+  const int leftpad = (ncdirect_dim_x(nc) - maxlinelen) / 2;
   for(int i = 0 ; i < linecount ; ++i){
     printf("%*.*s%s", leftpad, leftpad, "", lines[i]);
     free(lines[i]);
   }
   free(lines);
   ncdirect_set_fg_rgb(nc, 0xba55d3);
-  if(notcurses_canopen_images(NULL)){
+  if(ncdirect_canopen_images(nc)){
     ncdirect_printf_aligned(nc, -1, NCALIGN_CENTER, "(no image file is known for your distro)");
   }else{
     ncdirect_printf_aligned(nc, -1, NCALIGN_CENTER, "(notcurses was compiled without image support)");
@@ -565,15 +571,16 @@ static void*
 display_thread(void* vmarshal){
   struct marshal* m = vmarshal;
   drawpalette(m->nc);
-  if(notcurses_canopen_images(NULL)){
+  if(ncdirect_canopen_images(m->nc)){
+    ncdirect_check_pixel_support(m->nc);
     if(m->logo){
       if(ncdirect_render_image(m->nc, m->logo, NCALIGN_CENTER,
-                              NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES) == 0){
+                               NCBLIT_PIXEL, NCSCALE_SCALE_HIRES) == 0){
         return NULL;
       }
     }else if(m->dinfo && m->dinfo->logofile){
       if(ncdirect_render_image(m->nc, m->dinfo->logofile, NCALIGN_CENTER,
-                              NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES) == 0){
+                               NCBLIT_PIXEL, NCSCALE_SCALE_HIRES) == 0){
         return NULL;
       }
     }
