@@ -31,22 +31,11 @@ trilerp(uint32_t c0, uint32_t c1, uint32_t c2){
   return ret;
 }
 
-// alpha comes to us 0--255, but we have only 3 alpha values to map them to.
-// settled on experimentally.
-static inline bool
-ffmpeg_trans_p(unsigned char alpha){
-  if(alpha < 192){
-//fprintf(stderr, "TRANSPARENT!\n");
-    return true;
-  }
-  return false;
-}
-
 // Retarded RGBA blitter (ASCII only).
 static inline int
 tria_blit_ascii(ncplane* nc, int placey, int placex, int linesize,
                 const void* data, int begy, int begx,
-                int leny, int lenx, bool blendcolors){
+                int leny, int lenx, unsigned blendcolors){
 //fprintf(stderr, "ASCII %d X %d @ %d X %d (%p) place: %d X %d\n", leny, lenx, begy, begx, data, placey, placex);
   const int bpp = 32;
   int dimy, dimx, x, y;
@@ -72,7 +61,7 @@ tria_blit_ascii(ncplane* nc, int placey, int placex, int linesize,
         cell_set_bg_alpha(c, CELL_ALPHA_BLEND);
         cell_set_fg_alpha(c, CELL_ALPHA_BLEND);
       }
-      if(ffmpeg_trans_p(rgbbase_up[3])){
+      if(rgba_trans_p(rgbbase_up[3])){
         cell_set_bg_alpha(c, CELL_ALPHA_TRANSPARENT);
         cell_set_fg_alpha(c, CELL_ALPHA_TRANSPARENT);
         cell_set_blitquadrants(c, 0, 0, 0, 0);
@@ -95,7 +84,7 @@ tria_blit_ascii(ncplane* nc, int placey, int placex, int linesize,
 static inline int
 tria_blit(ncplane* nc, int placey, int placex, int linesize,
           const void* data, int begy, int begx,
-          int leny, int lenx, bool blendcolors){
+          int leny, int lenx, unsigned blendcolors){
 //fprintf(stderr, "HALF %d X %d @ %d X %d (%p) place: %d X %d\n", leny, lenx, begy, begx, data, placey, placex);
   const int bpp = 32;
   int dimy, dimx, x, y;
@@ -125,11 +114,11 @@ tria_blit(ncplane* nc, int placey, int placex, int linesize,
         cell_set_bg_alpha(c, CELL_ALPHA_BLEND);
         cell_set_fg_alpha(c, CELL_ALPHA_BLEND);
       }
-      if(ffmpeg_trans_p(rgbbase_up[3]) || ffmpeg_trans_p(rgbbase_down[3])){
+      if(rgba_trans_p(rgbbase_up[3]) || rgba_trans_p(rgbbase_down[3])){
         cell_set_bg_alpha(c, CELL_ALPHA_TRANSPARENT);
-        if(ffmpeg_trans_p(rgbbase_up[3]) && ffmpeg_trans_p(rgbbase_down[3])){
+        if(rgba_trans_p(rgbbase_up[3]) && rgba_trans_p(rgbbase_down[3])){
           cell_set_fg_alpha(c, CELL_ALPHA_TRANSPARENT);
-        }else if(ffmpeg_trans_p(rgbbase_up[3])){ // down has the color
+        }else if(rgba_trans_p(rgbbase_up[3])){ // down has the color
           if(pool_blit_direct(&nc->pool, c, "\u2584", strlen("\u2584"), 1) <= 0){
             return -1;
           }
@@ -175,6 +164,7 @@ rgb_diff(unsigned r1, unsigned g1, unsigned b1, unsigned r2, unsigned g2, unsign
   distance += r1 > r2 ? r1 - r2 : r2 - r1;
   distance += g1 > g2 ? g1 - g2 : g2 - g1;
   distance += b1 > b2 ? b1 - b2 : b2 - b1;
+//fprintf(stderr, "RGBDIFF %u %u %u %u %u %u: %u\n", r1, g1, b1, r2, g2, b2, distance);
   return distance;
 }
 
@@ -258,28 +248,51 @@ quadrant_solver(uint32_t tl, uint32_t tr, uint32_t bl, uint32_t br,
 //fprintf(stderr, "mindiff: %u[%zu] fore: %08x back: %08x %d+%d/%d+%d\n", mindiff, mindiffidx, *fore, *back, qd->pair[0], qd->pair[1], qd->others[0], qd->others[1]);
   const char* egc = qd->egc;
   // break down the excluded pair and lerp
-  unsigned r0, r1, g0, g1, b0, b1;
+  unsigned r0, r1, r2, g0, g1, g2, b0, b1, b2;
   unsigned roth, goth, both, rlerp, glerp, blerp;
+  channel_rgb8(*back, &roth, &goth, &both);
+  channel_rgb8(*fore, &rlerp, &glerp, &blerp);
+//fprintf(stderr, "rgbs: %02x %02x %02x / %02x %02x %02x\n", r0, g0, b0, r1, g1, b1);
+  // get diffs of the excluded two from both lerps
   channel_rgb8(colors[qd->others[0]], &r0, &g0, &b0);
   channel_rgb8(colors[qd->others[1]], &r1, &g1, &b1);
-  channel_rgb8(*fore, &rlerp, &glerp, &blerp);
-  channel_rgb8(*back, &roth, &goth, &both);
-//fprintf(stderr, "rgbs: %02x %02x %02x / %02x %02x %02x\n", r0, g0, b0, r1, g1, b1);
-  diffs[0] = rgb_diff(r0, g0, b0, rlerp, glerp, blerp);
-  diffs[1] = rgb_diff(r0, g0, b0, roth, goth, both);
-  diffs[2] = rgb_diff(r1, g1, b1, rlerp, glerp, blerp);
-  diffs[3] = rgb_diff(r1, g1, b1, roth, goth, both);
-//fprintf(stderr, "diffs: %08x %08x %08x %08x\n", diffs[0], diffs[1], diffs[2], diffs[3]);
-  if(diffs[0] < diffs[1] && diffs[0] < diffs[2]){
-    egc = qd->oth0egc;
-    *back = colors[qd->others[1]];
-    *fore = trilerp(colors[qd->pair[0]], colors[qd->pair[1]], colors[qd->others[0]]);
-//fprintf(stderr, "swap 1 %08x %08x\n", *fore, *back);
-  }else if(diffs[2] < diffs[3]){
-    egc = qd->oth1egc;
-    *back = colors[qd->others[0]];
-    *fore = trilerp(colors[qd->pair[0]], colors[qd->pair[1]], colors[qd->others[1]]);
-//fprintf(stderr, "swap 2 %08x %08x\n", *fore, *back);
+  diffs[0] = rgb_diff(r0, g0, b0, roth, goth, both);
+  diffs[1] = rgb_diff(r1, g1, b1, roth, goth, both);
+  diffs[2] = rgb_diff(r0, g0, b0, rlerp, glerp, blerp);
+  diffs[3] = rgb_diff(r1, g1, b1, rlerp, glerp, blerp);
+  // get diffs of the included two from their lerp
+  channel_rgb8(colors[qd->pair[0]], &r0, &g0, &b0);
+  channel_rgb8(colors[qd->pair[1]], &r1, &g1, &b1);
+  diffs[4] = rgb_diff(r0, g0, b0, rlerp, glerp, blerp);
+  diffs[5] = rgb_diff(r1, g1, b1, rlerp, glerp, blerp);
+  unsigned curdiff = diffs[0] + diffs[1] + diffs[4] + diffs[5];
+  // it might be better to combine three, and leave one totally unchanged.
+  // propose a trilerps; we only need consider the member of the excluded pair
+  // closer to the primary lerp. recalculate total diff; merge if lower.
+  if(diffs[2] < diffs[3]){
+    unsigned tri = trilerp(colors[qd->pair[0]], colors[qd->pair[1]], colors[qd->others[0]]);
+    channel_rgb8(colors[qd->others[0]], &r2, &g2, &b2);
+    channel_rgb8(tri, &roth, &goth, &both);
+    if(rgb_diff(r0, g0, b0, roth, goth, both) +
+       rgb_diff(r1, g1, b1, roth, goth, both) +
+       rgb_diff(r2, g2, b2, roth, goth, both) < curdiff){
+      egc = qd->oth0egc;
+      *back = colors[qd->others[1]];
+      *fore = tri;
+    }
+//fprintf(stderr, "quadblitter swap type 1\n");
+  }else{
+    unsigned tri = trilerp(colors[qd->pair[0]], colors[qd->pair[1]], colors[qd->others[1]]);
+    channel_rgb8(colors[qd->others[1]], &r2, &g2, &b2);
+    channel_rgb8(tri, &roth, &goth, &both);
+    if(rgb_diff(r0, g0, b0, roth, goth, both) +
+       rgb_diff(r1, g1, b1, roth, goth, both) +
+       rgb_diff(r2, g2, b2, roth, goth, both) < curdiff){
+      egc = qd->oth1egc;
+      *back = colors[qd->others[0]];
+      *fore = tri;
+    }
+//fprintf(stderr, "quadblitter swap type 2\n");
   }
   return egc;
 }
@@ -293,7 +306,7 @@ quadrant_solver(uint32_t tl, uint32_t tr, uint32_t bl, uint32_t br,
 // FIXME we ought be able to just build up a bitstring and use it as an index!
 // FIXME pass in rgbas as array of uint32_t ala sexblitter
 static inline const char*
-qtrans_check(nccell* c, bool blendcolors,
+qtrans_check(nccell* c, unsigned blendcolors,
              const unsigned char* rgbbase_tl, const unsigned char* rgbbase_tr,
              const unsigned char* rgbbase_bl, const unsigned char* rgbbase_br){
   uint32_t tl = 0, tr = 0, bl = 0, br = 0;
@@ -302,13 +315,13 @@ qtrans_check(nccell* c, bool blendcolors,
   channel_set_rgb8(&bl, rgbbase_bl[0], rgbbase_bl[1], rgbbase_bl[2]);
   channel_set_rgb8(&br, rgbbase_br[0], rgbbase_br[1], rgbbase_br[2]);
   const char* egc = NULL;
-  if(ffmpeg_trans_p(rgbbase_tl[3])){
+  if(rgba_trans_p(rgbbase_tl[3])){
     // top left is transparent
-    if(ffmpeg_trans_p(rgbbase_tr[3])){
+    if(rgba_trans_p(rgbbase_tr[3])){
       // all of top is transparent
-      if(ffmpeg_trans_p(rgbbase_bl[3])){
+      if(rgba_trans_p(rgbbase_bl[3])){
         // top and left are transparent
-        if(ffmpeg_trans_p(rgbbase_br[3])){
+        if(rgba_trans_p(rgbbase_br[3])){
           // entirety is transparent, load with nul (but not NULL)
           cell_set_fg_default(c);
           cell_set_blitquadrants(c, 0, 0, 0, 0);
@@ -319,7 +332,7 @@ qtrans_check(nccell* c, bool blendcolors,
           egc = "▗";
         }
       }else{
-        if(ffmpeg_trans_p(rgbbase_br[3])){
+        if(rgba_trans_p(rgbbase_br[3])){
           cell_set_fg_rgb8(c, rgbbase_bl[0], rgbbase_bl[1], rgbbase_bl[2]);
           cell_set_blitquadrants(c, 0, 0, 1, 0);
           egc = "▖";
@@ -330,8 +343,8 @@ qtrans_check(nccell* c, bool blendcolors,
         }
       }
     }else{ // top right is foreground, top left is transparent
-      if(ffmpeg_trans_p(rgbbase_bl[3])){
-        if(ffmpeg_trans_p(rgbbase_br[3])){ // entire bottom is transparent
+      if(rgba_trans_p(rgbbase_bl[3])){
+        if(rgba_trans_p(rgbbase_br[3])){ // entire bottom is transparent
           cell_set_fg_rgb8(c, rgbbase_tr[0], rgbbase_tr[1], rgbbase_tr[2]);
           cell_set_blitquadrants(c, 0, 1, 0, 0);
           egc = "▝";
@@ -340,7 +353,7 @@ qtrans_check(nccell* c, bool blendcolors,
           cell_set_blitquadrants(c, 0, 1, 0, 1);
           egc = "▐";
         }
-      }else if(ffmpeg_trans_p(rgbbase_br[3])){ // only br is transparent
+      }else if(rgba_trans_p(rgbbase_br[3])){ // only br is transparent
         cell_set_fchannel(c, lerp(tr, bl));
         cell_set_blitquadrants(c, 0, 1, 1, 0);
         egc = "▞";
@@ -351,9 +364,9 @@ qtrans_check(nccell* c, bool blendcolors,
       }
     }
   }else{ // topleft is foreground for all here
-    if(ffmpeg_trans_p(rgbbase_tr[3])){
-      if(ffmpeg_trans_p(rgbbase_bl[3])){
-        if(ffmpeg_trans_p(rgbbase_br[3])){
+    if(rgba_trans_p(rgbbase_tr[3])){
+      if(rgba_trans_p(rgbbase_bl[3])){
+        if(rgba_trans_p(rgbbase_br[3])){
           cell_set_fg_rgb8(c, rgbbase_tl[0], rgbbase_tl[1], rgbbase_tl[2]);
           cell_set_blitquadrants(c, 1, 0, 0, 0);
           egc = "▘";
@@ -362,7 +375,7 @@ qtrans_check(nccell* c, bool blendcolors,
           cell_set_blitquadrants(c, 1, 0, 0, 1);
           egc = "▚";
         }
-      }else if(ffmpeg_trans_p(rgbbase_br[3])){
+      }else if(rgba_trans_p(rgbbase_br[3])){
         cell_set_fchannel(c, lerp(tl, bl));
         cell_set_blitquadrants(c, 1, 0, 1, 0);
         egc = "▌";
@@ -371,8 +384,8 @@ qtrans_check(nccell* c, bool blendcolors,
         cell_set_blitquadrants(c, 1, 0, 1, 1);
         egc = "▙";
       }
-    }else if(ffmpeg_trans_p(rgbbase_bl[3])){
-      if(ffmpeg_trans_p(rgbbase_br[3])){ // entire bottom is transparent
+    }else if(rgba_trans_p(rgbbase_bl[3])){
+      if(rgba_trans_p(rgbbase_br[3])){ // entire bottom is transparent
         cell_set_fchannel(c, lerp(tl, tr));
         cell_set_blitquadrants(c, 1, 1, 0, 0);
         egc = "▀";
@@ -381,7 +394,7 @@ qtrans_check(nccell* c, bool blendcolors,
         cell_set_blitquadrants(c, 1, 1, 0, 1);
         egc = "▜";
       }
-    }else if(ffmpeg_trans_p(rgbbase_br[3])){ // only br is transparent
+    }else if(rgba_trans_p(rgbbase_br[3])){ // only br is transparent
       cell_set_fchannel(c, trilerp(tl, tr, bl));
       cell_set_blitquadrants(c, 1, 1, 1, 0);
       egc = "▛";
@@ -405,7 +418,7 @@ qtrans_check(nccell* c, bool blendcolors,
 static inline int
 quadrant_blit(ncplane* nc, int placey, int placex, int linesize,
               const void* data, int begy, int begx,
-              int leny, int lenx, bool blendcolors){
+              int leny, int lenx, unsigned blendcolors){
   const int bpp = 32;
   int dimy, dimx, x, y;
   int total = 0; // number of cells written
@@ -488,21 +501,21 @@ generalerp(unsigned rsum, unsigned gsum, unsigned bsum, int count){
 // (all six pixels are different colors). We want to solve for the 2-partition
 // of pixels that minimizes total source distance from the resulting lerps.
 static const char*
-sex_solver(const uint32_t rgbas[6], uint64_t* channels, bool blendcolors){
-	static const char* sex[69] = {
-	  " ", "🬀", "🬁", "🬃", "🬇", "🬏", "🬞", "🬂",
-	  "🬄", "🬈", "🬐", "🬟", "🬅", "🬉", "🬑", "🬠",
-	  "🬋", "🬓", "🬢", "🬖", "🬦", "🬭", "🬆", "🬊",
-	  "🬒", "🬡", "🬌", "▌", "🬣", "🬗", "🬧", "🬍",
-	  "█", "🬻", "🬺", "🬸", "🬴", "🬬", "🬝", "🬹",
-	  "🬷", "🬳", "🬫", "🬜", "🬶", "🬲", "🬪", "🬛",
-	  "🬰", "🬨", "🬙", "🬥", "🬕", "🬎", "🬵", "🬱",
-	  "🬩", "🬚", "🬯", "▐", "🬘", "🬤", "🬔", "🬮",
-    "n", "i", "c", "e"
-	};
+sex_solver(const uint32_t rgbas[6], uint64_t* channels, unsigned blendcolors){
   // each element within the set of 64 has an inverse element within the set,
-  // for which we will calculate the same total differences, so just handle the
-  // first 32, and then assign fg to whichever cluster is larger.
+  // for which we would calculate the same total differences, so just handle
+  // the first 32. the partition[] bit masks represent combinations of
+  // sextants, and their indices correspond to sex[].
+  static const char* sex[32] = {
+    " ", "🬀", "🬁", "🬃", "🬇", "🬏", "🬞", "🬂", // 0..7
+
+    "🬄", "🬈", "🬐", "🬟", "🬅", "🬉", "🬑", "🬠", // 8..15
+
+    "🬋", "🬓", "🬢", "🬖", "🬦", "🬭", "🬆", "🬊", // 16..23
+
+    "🬒", "🬡", "🬌", "▌", "🬣", "🬗", "🬧", "🬍", // 24..31
+
+  };
   static const unsigned partitions[32] = {
     0, // 1 way to arrange 0
     1, 2, 4, 8, 16, 32, // 6 ways to arrange 1
@@ -533,9 +546,9 @@ sex_solver(const uint32_t rgbas[6], uint64_t* channels, bool blendcolors){
         bsum1 += ncpixel_b(rgbas[mask]);
       }
     }
-//fprintf(stderr, "sum0: %u/%u/%u sum1: %u/%u/%u insum: %d\n", rsum0, gsum0, bsum0, rsum1, gsum1, bsum1, insum);
     uint32_t l0 = generalerp(rsum0, gsum0, bsum0, insum);
     uint32_t l1 = generalerp(rsum1, gsum1, bsum1, 6 - insum);
+//fprintf(stderr, "sum0: %06x sum1: %06x insum: %d\n", l0 & 0xffffffu, l1 & 0xffffffu, insum);
     uint32_t totaldiff = 0;
     for(unsigned mask = 0 ; mask < 6 ; ++mask){
       unsigned r, g, b;
@@ -544,11 +557,12 @@ sex_solver(const uint32_t rgbas[6], uint64_t* channels, bool blendcolors){
       }else{
         channel_rgb8(l1, &r, &g, &b);
       }
-      totaldiff += rgb_diff(ncpixel_r(rgbas[mask]), ncpixel_g(rgbas[mask]),
-                            ncpixel_b(rgbas[mask]), r, g, b);
+      uint32_t rdiff = rgb_diff(ncpixel_r(rgbas[mask]), ncpixel_g(rgbas[mask]),
+                                ncpixel_b(rgbas[mask]), r, g, b);
+      totaldiff += rdiff;
 //fprintf(stderr, "mask: %u totaldiff: %u insum: %d (%08x / %08x)\n", mask, totaldiff, insum, l0, l1);
     }
-//fprintf(stderr, "bits: %u %zu totaldiff: %u best: %u (%d)\n", partitions[glyph], glyph, totaldiff, mindiff, best);
+//fprintf(stderr, "bits: %u %zu totaldiff: %f best: %f (%d)\n", partitions[glyph], glyph, totaldiff, mindiff, best);
     if(totaldiff < mindiff){
       mindiff = totaldiff;
       best = glyph;
@@ -560,7 +574,7 @@ sex_solver(const uint32_t rgbas[6], uint64_t* channels, bool blendcolors){
     }
   }
 //fprintf(stderr, "solved for best: %d (%u)\n", best, mindiff);
-  assert(best >= 0 && best < 64);
+  assert(best >= 0 && best < 32);
   if(blendcolors){
     channels_set_fg_alpha(channels, CELL_ALPHA_BLEND);
     channels_set_bg_alpha(channels, CELL_ALPHA_BLEND);
@@ -569,7 +583,7 @@ sex_solver(const uint32_t rgbas[6], uint64_t* channels, bool blendcolors){
 }
 
 static const char*
-sex_trans_check(cell* c, const uint32_t rgbas[6], bool blendcolors){
+sex_trans_check(cell* c, const uint32_t rgbas[6], unsigned blendcolors){
   // bit is *set* where sextant *is not*
   // 32: bottom right 16: bottom left
   //  8: middle right  4: middle left
@@ -588,7 +602,7 @@ sex_trans_check(cell* c, const uint32_t rgbas[6], bool blendcolors){
   unsigned r = 0, g = 0, b = 0;
   unsigned div = 0;
   for(unsigned mask = 0 ; mask < 6 ; ++mask){
-    if(ffmpeg_trans_p(ncpixel_a(rgbas[mask]))){
+    if(rgba_trans_p(ncpixel_a(rgbas[mask]))){
       transstring |= (1u << mask);
     }else{
       r += ncpixel_r(rgbas[mask]);
@@ -627,7 +641,7 @@ sex_trans_check(cell* c, const uint32_t rgbas[6], bool blendcolors){
 static inline int
 sextant_blit(ncplane* nc, int placey, int placex, int linesize,
              const void* data, int begy, int begx,
-             int leny, int lenx, bool blendcolors){
+             int leny, int lenx, unsigned blendcolors){
   const int bpp = 32;
   int dimy, dimx, x, y;
   int total = 0; // number of cells written
@@ -696,7 +710,7 @@ fold_rgb8(unsigned* restrict r, unsigned* restrict g, unsigned* restrict b,
 static inline int
 braille_blit(ncplane* nc, int placey, int placex, int linesize,
              const void* data, int begy, int begx,
-             int leny, int lenx, bool blendcolors){
+             int leny, int lenx, unsigned blendcolors){
   const int bpp = 32;
   int dimy, dimx, x, y;
   int total = 0; // number of cells written
@@ -743,35 +757,35 @@ braille_blit(ncplane* nc, int placey, int placex, int linesize,
         }
       }
       // FIXME fold this into the above?
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_l0))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_l0))){
         egcidx |= 1u;
         fold_rgb8(&r, &g, &b, rgbbase_l0, &blends);
       }
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_l1))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_l1))){
         egcidx |= 2u;
         fold_rgb8(&r, &g, &b, rgbbase_l1, &blends);
       }
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_l2))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_l2))){
         egcidx |= 4u;
         fold_rgb8(&r, &g, &b, rgbbase_l2, &blends);
       }
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_r0))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_r0))){
         egcidx |= 8u;
         fold_rgb8(&r, &g, &b, rgbbase_r0, &blends);
       }
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_r1))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_r1))){
         egcidx |= 16u;
         fold_rgb8(&r, &g, &b, rgbbase_r1, &blends);
       }
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_r2))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_r2))){
         egcidx |= 32u;
         fold_rgb8(&r, &g, &b, rgbbase_r2, &blends);
       }
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_l3))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_l3))){
         egcidx |= 64u;
         fold_rgb8(&r, &g, &b, rgbbase_l3, &blends);
       }
-      if(!ffmpeg_trans_p(ncpixel_a(*rgbbase_r3))){
+      if(!rgba_trans_p(ncpixel_a(*rgbbase_r3))){
         egcidx |= 128u;
         fold_rgb8(&r, &g, &b, rgbbase_r3, &blends);
       }
@@ -812,23 +826,23 @@ braille_blit(ncplane* nc, int placey, int placex, int linesize,
 
 // NCBLIT_DEFAULT is not included, as it has no defined properties. It ought
 // be replaced with some real blitter implementation by the calling widget.
-const struct blitset notcurses_blitters[] = {
+static const struct blitset notcurses_blitters[] = {
    { .geom = NCBLIT_8x1,     .width = 1, .height = 8, .egcs = L" ▁▂▃▄▅▆▇█",
      .blit = tria_blit,      .name = "eightstep",     .fill = false, },
    { .geom = NCBLIT_1x1,     .width = 1, .height = 1, .egcs = L" █",
      .blit = tria_blit_ascii,.name = "ascii",         .fill = false, },
    { .geom = NCBLIT_2x1,     .width = 1, .height = 2, .egcs = L" ▄█",
-     .blit = tria_blit,      .name = "halfblock",     .fill = false, },
+     .blit = tria_blit,      .name = "half",          .fill = false, },
    { .geom = NCBLIT_2x2,     .width = 2, .height = 2, .egcs = L" ▗▐▖▄▟▌▙█",
-     .blit = quadrant_blit,  .name = "quadblitter",   .fill = false, },
+     .blit = quadrant_blit,  .name = "quad",          .fill = false, },
    { .geom = NCBLIT_3x2,     .width = 2, .height = 3, .egcs = L" 🬞🬦▐🬏🬭🬵🬷🬓🬱🬹🬻▌🬲🬺█",
-     .blit = sextant_blit,   .name = "sexblitter",    .fill = false, },
+     .blit = sextant_blit,   .name = "sex",           .fill = false, },
    { .geom = NCBLIT_4x1,     .width = 1, .height = 4, .egcs = L" ▂▄▆█",
      .blit = tria_blit,      .name = "fourstep",      .fill = false, },
    { .geom = NCBLIT_BRAILLE, .width = 2, .height = 4, .egcs = L"⠀⢀⢠⢰⢸⡀⣀⣠⣰⣸⡄⣄⣤⣴⣼⡆⣆⣦⣶⣾⡇⣇⣧⣷⣿",
      .blit = braille_blit,   .name = "braille",       .fill = true,  },
-   { .geom = NCBLIT_SIXEL,   .width = 1, .height = 6, .egcs = L"",
-     .blit = NULL,           .name = "sixel",         .fill = true,  }, // FIXME
+   { .geom = NCBLIT_PIXEL,   .width = 1, .height = 1, .egcs = L"",
+     .blit = sixel_blit,     .name = "pixel",         .fill = true,  },
    { .geom = 0,              .width = 0, .height = 0, .egcs = NULL,
      .blit = NULL,           .name = NULL,            .fill = false,  },
 };
@@ -912,6 +926,52 @@ int ncblit_rgba(const void* data, int linesize, const struct ncvisual_options* v
                     leny, lenx, blend);
 }
 
+const struct blitset* lookup_blitset(const tinfo* tcache, ncblitter_e setid, bool may_degrade) {
+  if(setid == NCBLIT_DEFAULT){ // ought have resolved NCBLIT_DEFAULT before now
+    return NULL;
+  }
+  // without braille support, NCBLIT_BRAILLE decays to NCBLIT_3x2
+  if(!tcache->braille && setid == NCBLIT_BRAILLE){
+    if(may_degrade){
+      setid = NCBLIT_3x2;
+    }else{
+      return NULL;
+    }
+  }
+  // without pixel support, NCBLIT_PIXEL decays to NCBLIT_3x2
+  if(!tcache->sixel_supported && setid == NCBLIT_PIXEL){
+    if(may_degrade){
+      setid = NCBLIT_3x2;
+    }else{
+      return NULL;
+    }
+  }
+  // without sextant support, NCBLIT_3x2 decays to NCBLIT_2x2
+  if(!tcache->sextants && setid == NCBLIT_3x2){
+    if(may_degrade){
+      setid = NCBLIT_2x2;
+    }else{
+      return NULL;
+    }
+  }
+  // the only viable blitter in ASCII is NCBLIT_1x1
+  if(!tcache->utf8 && setid != NCBLIT_1x1){
+    if(may_degrade){
+      setid = NCBLIT_1x1;
+    }else{
+      return NULL;
+    }
+  }
+  const struct blitset* bset = notcurses_blitters;
+  while(bset->egcs){
+    if(bset->geom == setid){
+      return bset;
+    }
+    ++bset;
+  }
+  return NULL;
+}
+
 ncblitter_e ncvisual_media_defblitter(const notcurses* nc, ncscale_e scale){
   return rgba_blitter_default(&nc->tcache, scale);
 }
