@@ -10,21 +10,6 @@
 #include "notcurses/direct.h"
 #include "internal.h"
 
-static inline uint64_t
-ncdirect_channels(const ncdirect* nc){
-  return nc->channels;
-}
-
-static inline bool
-ncdirect_fg_default_p(const struct ncdirect* nc){
-  return channels_fg_default_p(ncdirect_channels(nc));
-}
-
-static inline bool
-ncdirect_bg_default_p(const struct ncdirect* nc){
-  return channels_bg_default_p(ncdirect_channels(nc));
-}
-
 int ncdirect_putstr(ncdirect* nc, uint64_t channels, const char* utf8){
   if(channels_fg_default_p(channels)){
     if(ncdirect_set_fg_default(nc)){
@@ -101,7 +86,7 @@ int ncdirect_clear(ncdirect* nc){
 int ncdirect_dim_x(const ncdirect* nc){
   int x;
   if(nc->ctermfd >= 0){
-    if(update_term_dimensions(nc->ctermfd, nullptr, &x) == 0){
+    if(update_term_dimensions(nc->ctermfd, nullptr, &x, NULL) == 0){
       return x;
     }
   }else{
@@ -113,7 +98,7 @@ int ncdirect_dim_x(const ncdirect* nc){
 int ncdirect_dim_y(const ncdirect* nc){
   int y;
   if(nc->ctermfd >= 0){
-    if(update_term_dimensions(nc->ctermfd, &y, nullptr) == 0){
+    if(update_term_dimensions(nc->ctermfd, &y, nullptr, NULL) == 0){
       return y;
     }
   }else{
@@ -161,7 +146,7 @@ int ncdirect_cursor_move_yx(ncdirect* n, int y, int x){
 
 static int
 cursor_yx_get(int ttyfd, int* y, int* x){
-  if(write(ttyfd, "\033[6n", 4) != 4){
+  if(writen(ttyfd, "\033[6n", 4) != 4){
     return -1;
   }
   bool done = false;
@@ -492,14 +477,19 @@ ncdirectv* ncdirect_render_frame(ncdirect* n, const char* file,
   }
   int disprows, dispcols;
   if(scale != NCSCALE_NONE && scale != NCSCALE_NONE_HIRES){
-    dispcols = ncdirect_dim_x(n) * encoding_x_scale(bset);
-    disprows = ncdirect_dim_y(n) * encoding_y_scale(bset);
+    if(bset->geom != NCBLIT_PIXEL){
+      dispcols = ncdirect_dim_x(n) * encoding_x_scale(&n->tcache, bset);
+      disprows = ncdirect_dim_y(n) * encoding_y_scale(&n->tcache, bset);
+    }else{
+      dispcols = ncdirect_dim_x(n) * n->tcache.cellpixx;
+      disprows = ncdirect_dim_y(n) * n->tcache.cellpixy;
+    }
     if(scale == NCSCALE_SCALE || scale == NCSCALE_SCALE_HIRES){
       scale_visual(ncv, &disprows, &dispcols);
     }
   }else{
     disprows = ncv->rows;
-    dispcols = ncv->cols / encoding_x_scale(bset);
+    dispcols = ncv->cols;
   }
   leny = (leny / (double)ncv->rows) * ((double)disprows);
   lenx = (lenx / (double)ncv->cols) * ((double)dispcols);
@@ -507,20 +497,24 @@ ncdirectv* ncdirect_render_frame(ncdirect* n, const char* file,
   ncplane_options nopts = {
     .y = 0,
     .x = 0,
-    .rows = disprows / encoding_y_scale(bset),
-    .cols = dispcols / encoding_x_scale(bset),
+    .rows = disprows / encoding_y_scale(&n->tcache, bset),
+    .cols = dispcols / encoding_x_scale(&n->tcache, bset),
     .userptr = nullptr,
     .name = "fake",
     .resizecb = nullptr,
     .flags = 0,
   };
+  if(bset->geom == NCBLIT_PIXEL){
+    nopts.rows = 1;
+    nopts.cols = dispcols / n->tcache.cellpixx;
+  }
   auto ncdv = ncplane_new_internal(nullptr, nullptr, &nopts);
   if(!ncdv){
     ncvisual_destroy(ncv);
     return nullptr;
   }
   if(ncvisual_blit(ncv, disprows, dispcols, ncdv, bset,
-                   0, 0, 0, 0, leny, lenx, false)){
+                   0, 0, 0, 0, leny, lenx, n->tcache.cellpixx)){
     ncvisual_destroy(ncv);
     free_plane(ncdv);
     return nullptr;
@@ -617,6 +611,7 @@ ncdirect_stop_minimal(void* vnc){
     ret |= close(nc->ctermfd);
   }
   ret |= ncdirect_flush(nc);
+  free_terminfo_cache(&nc->tcache);
   return ret;
 }
 
@@ -675,6 +670,7 @@ ncdirect* ncdirect_core_init(const char* termtype, FILE* outfp, uint64_t flags){
   if(interrogate_terminfo(&ret->tcache, shortname_term, utf8)){
     goto err;
   }
+  update_term_dimensions(ret->ctermfd, NULL, NULL, &ret->tcache);
   ncdirect_set_styles(ret, 0);
   return ret;
 
@@ -1079,3 +1075,13 @@ int ncdirect_flush(const ncdirect* nc){
   }
   return 0;
 }
+
+int ncdirect_check_pixel_support(ncdirect* n){
+  if(query_term(&n->tcache, n->ctermfd)){
+    return -1;
+  }
+  if(n->tcache.sixel_supported){
+    return 1;
+  }
+  return 0;
+}
