@@ -119,7 +119,7 @@ int ncplane_fadein_iteration(ncplane* n, ncfadectx* nctx, int iter,
       channels_fg_rgb8(nctx->channels[nctx->cols * y + x], &r, &g, &b);
       unsigned br, bg, bb;
       channels_bg_rgb8(nctx->channels[nctx->cols * y + x], &br, &bg, &bb);
-      cell* c = &n->fb[dimx * y + x];
+      nccell* c = &n->fb[dimx * y + x];
       if(!cell_fg_default_p(c)){
         r = r * iter / nctx->maxsteps;
         g = g * iter / nctx->maxsteps;
@@ -182,7 +182,7 @@ int ncplane_fadeout_iteration(ncplane* n, ncfadectx* nctx, int iter,
   ncplane_dim_yx(n, &dimy, &dimx);
   for(y = 0 ; y < nctx->rows && y < dimy ; ++y){
     for(x = 0 ; x < nctx->cols && x < dimx; ++x){
-      cell* c = &n->fb[dimx * y + x];
+      nccell* c = &n->fb[dimx * y + x];
       if(!cell_fg_default_p(c)){
         channels_fg_rgb8(nctx->channels[nctx->cols * y + x], &r, &g, &b);
         r = r * (nctx->maxsteps - iter) / nctx->maxsteps;
@@ -199,7 +199,7 @@ int ncplane_fadeout_iteration(ncplane* n, ncfadectx* nctx, int iter,
       }
     }
   }
-  cell* c = &n->basecell;
+  nccell* c = &n->basecell;
   if(!cell_fg_default_p(c)){
     channels_fg_rgb8(nctx->channels[nctx->cols * y], &r, &g, &b);
     r = r * (nctx->maxsteps - iter) / nctx->maxsteps;
