@@ -39,9 +39,13 @@ struct ncvisual_details;
 #define CELL_NOBACKGROUND_MASK  0x8700000000000000ull
 
 // Was this glyph drawn as part of an ncvisual? If so, we need to honor
-// blitter stacking rather than the standard trichannel solver.
+// blitter stacking rather than the standard trichannel solver (yes, this
+// is the same as CELL_NOBACKGROUND_MASK).
 #define CELL_BLITTERSTACK_MASK  0x8700000000000000ull
 
+// if this bit is set, the cell ought be rasterized in pixel graphics mode.
+#define CELL_PIXEL_GRAPHICS     0x0000000080000000ull
+
 // we can't define multipart ncvisual here, because OIIO requires C++ syntax,
 // and we can't go throwing C++ syntax into this header. so it goes.
 
@@ -275,14 +279,21 @@ typedef struct tinfo {
   bool AMflag;    // "AM" flag for automatic movement to next line
   bool utf8;      // are we using utf-8 encoding, as hoped?
 
+  // we use the cell's size in pixels for pixel blitting. this information can
+  // be acquired on all terminals with pixel support.
+  int cellpixy;   // cell pixel height, might be 0
+  int cellpixx;   // cell pixel width, might be 0
+
   // kitty interprets an RGB background that matches the default background
   // color *as* the default background, meaning it'll be translucent if
   // background_opaque is in use. detect this, and avoid the default if so.
   // bg_collides_default is either 0x0000000 or 0x1RRGGBB.
   uint32_t bg_collides_default;
+  pthread_mutex_t pixel_query; // only query for pixel support once
+  bool sixel_supported;  // do we support sixel (post pixel_query_done)?
+  bool pixel_query_done; // have we yet performed pixel query?
   bool sextants;  // do we have (good, vetted) Unicode 13 sextant support?
   bool braille;   // do we have Braille support? (linux console does not)
-  bool libsixel;  // do we have Sixel support?
 } tinfo;
 
 typedef struct ncinputlayer {
@@ -348,8 +359,9 @@ typedef struct notcurses {
   int cursory;    // desired cursor placement according to user.
   int cursorx;    // -1 is don't-care, otherwise moved here after each render.
 
-  pthread_mutex_t statlock;
+  pthread_mutex_t statlock; // FIXME align on cacheline
   ncstats stats;  // some statistics across the lifetime of the notcurses ctx
+  ncstats stashed_stats; // retain across a notcurses_stats_reset(), to print in closing banner
 
   FILE* ttyfp;    // FILE* for writing rasterized data
   int ttyfd;      // file descriptor for controlling tty
@@ -365,16 +377,44 @@ typedef struct notcurses {
   int loglevel;
   palette256 palette; // 256-indexed palette can be used instead of/with RGB
   bool palette_damage[NCPALETTESIZE];
+  unsigned stdio_blocking_save; // was stdio blocking at entry? restore on stop.
 } notcurses;
 
+// a system for rendering RGBA pixels as text glyphs
+struct blitset {
+  ncblitter_e geom;
+  int width;
+  int height;
+  // the EGCs which form the various levels of a given plotset. if the geometry
+  // is wide, things are arranged with the rightmost side increasing most
+  // quickly, i.e. it can be indexed as height arrays of 1 + height glyphs. i.e.
+  // the first five braille EGCs are all 0 on the left, [0..4] on the right.
+  const wchar_t* egcs;
+  int (*blit)(struct ncplane* n, int placey, int placex,
+              int linesize, const void* data, int begy, int begx,
+              int leny, int lenx, unsigned blendcolors);
+  const char* name;
+  bool fill;
+};
+
 #include "blitset.h"
 
 void sigwinch_handler(int signo);
 
 void init_lang(notcurses* nc); // nc may be NULL, only used for logging
 int terminfostr(char** gseq, const char* name);
+
+// load |ti| from the terminfo database, which must already have been
+// initialized. set |utf8| if we've verified UTF8 output encoding.
 int interrogate_terminfo(tinfo* ti, const char* termname, unsigned utf8);
 
+void free_terminfo_cache(tinfo* ti);
+
+// perform queries that require writing to the terminal, and reading a
+// response, rather than simply reading the terminfo database. can result
+// in a lengthy delay or even block if the terminal doesn't respond.
+int query_term(tinfo* ti, int fd);
+
 // if there were missing elements we wanted from terminfo, bitch about them here
 void warn_terminfo(const notcurses* nc, const tinfo* ti);
 
@@ -507,26 +547,30 @@ rgb_greyscale(int r, int g, int b){
   return fg * 255;
 }
 
+// write(2) with retry on partial write or interrupted write
+static inline ssize_t
+writen(int fd, const void* buf, size_t len){
+  ssize_t r;
+  size_t w = 0;
+  while(w < len){
+    if((r = write(fd, (const char*)buf + w, len - w)) < 0){
+      if(errno == EAGAIN || errno == EBUSY || errno == EINTR){
+        continue;
+      }
+      return -1;
+    }
+    w += r;
+  }
+  return w;
+}
+
 static inline int
 tty_emit(const char* seq, int fd){
   if(!seq){
     return -1;
   }
   size_t slen = strlen(seq);
-  size_t written = 0;
-  do{
-    ssize_t ret = write(fd, seq, slen);
-    if(ret > 0){
-      written += ret;
-    }
-    if(ret < 0){
-      if(errno != EAGAIN){
-        break;
-      }
-    }
-  }while(written < slen);
-  if(written < slen){
-//fprintf(stderr, "Error emitting %zub escape (%s)\n", strlen(seq), strerror(errno));
+  if(writen(fd, seq, slen) < 0){
     return -1;
   }
   return 0;
@@ -543,7 +587,7 @@ term_emit(const char* seq, FILE* out, bool flush){
   }
   if(flush){
     while(fflush(out) == EOF){
-      if(errno != EAGAIN){
+      if(errno != EAGAIN && errno != EINTR && errno != EBUSY){
         fprintf(stderr, "Error flushing after %zub sequence (%s)\n", strlen(seq), strerror(errno));
         return -1;
       }
@@ -583,7 +627,7 @@ ncplane_cell_ref_yx(ncplane* n, int y, int x){
 
 static inline void
 cell_debug(const egcpool* p, const nccell* c){
-  fprintf(stderr, "gcluster: %u %s style: 0x%04x chan: 0x%016jx\n",
+  fprintf(stderr, "gcluster: %08x %s style: 0x%04x chan: 0x%016jx\n",
 				  c->gcluster, egcpool_extended_gcluster(p, c), c->stylemask, c->channels);
 }
 
@@ -603,6 +647,26 @@ plane_debug(const ncplane* n, bool details){
   }
 }
 
+static inline unsigned
+channels_pixel_p(uint64_t channels){
+  return channels & CELL_PIXEL_GRAPHICS;
+}
+
+static inline unsigned
+cell_pixels_p(const nccell* c){
+  return channels_pixel_p(c->channels);
+}
+
+static inline nccell*
+cell_set_pixels(nccell* c, unsigned p){
+  if(p){
+    c->channels |= CELL_PIXEL_GRAPHICS;
+  }else{
+    c->channels &= ~CELL_PIXEL_GRAPHICS;
+  }
+  return c;
+}
+
 static inline void
 pool_release(egcpool* pool, nccell* c){
   if(!cell_simple_p(c)){
@@ -642,7 +706,7 @@ int ncplane_resize_internal(ncplane* n, int keepy, int keepx,
                             int keepleny, int keeplenx, int yoff, int xoff,
                             int ylen, int xlen);
 
-int update_term_dimensions(int fd, int* rows, int* cols);
+int update_term_dimensions(int fd, int* rows, int* cols, tinfo* tcache);
 
 ALLOC static inline void*
 memdup(const void* src, size_t len){
@@ -655,12 +719,24 @@ memdup(const void* src, size_t len){
 
 ALLOC void* bgra_to_rgba(const void* data, int rows, int rowstride, int cols);
 
-static inline int
-rgba_blit_dispatch(ncplane* nc, const struct blitset* bset, int placey,
-                   int placex, int linesize, const void* data, int begy,
-                   int begx, int leny, int lenx, bool blendcolors){
-  return bset->blit(nc, placey, placex, linesize, data, begy, begx,
-                    leny, lenx, blendcolors);
+API const struct blitset* lookup_blitset(const tinfo* tcache, ncblitter_e setid, bool may_degrade);
+
+static inline const struct blitset*
+rgba_blitter_low(const tinfo* tcache, ncscale_e scale, bool maydegrade,
+                 ncblitter_e blitrec) {
+  if(blitrec == NCBLIT_DEFAULT){
+    blitrec = rgba_blitter_default(tcache, scale);
+  }
+  return lookup_blitset(tcache, blitrec, maydegrade);
+}
+
+// RGBA visuals all use NCBLIT_2x1 by default (or NCBLIT_1x1 if not in
+// UTF-8 mode), but an alternative can be specified.
+static inline const struct blitset*
+rgba_blitter(const struct notcurses* nc, const struct ncvisual_options* opts) {
+  const bool maydegrade = !(opts && (opts->flags & NCVISUAL_OPTION_NODEGRADE));
+  const ncscale_e scale = opts ? opts->scaling : NCSCALE_NONE;
+  return rgba_blitter_low(&nc->tcache, scale, maydegrade, opts ? opts->blitter : NCBLIT_DEFAULT);
 }
 
 // find the "center" cell of two lengths. in the case of even rows/columns, we
@@ -882,6 +958,52 @@ cell_set_blitquadrants(nccell* c, unsigned tl, unsigned tr, unsigned bl, unsigne
 // Destroy a plane and all its bound descendants.
 int ncplane_genocide(ncplane *ncp);
 
+// Extract the 32-bit background channel from a cell.
+static inline uint32_t
+cell_bchannel(const nccell* cl){
+  return channels_bchannel(cl->channels);
+}
+
+// Extract those elements of the channel which are common to both foreground
+// and background channel representations.
+static inline uint32_t
+channel_common(uint32_t channel){
+  return channel & (CELL_BGDEFAULT_MASK | CELL_BG_RGB_MASK |
+                    CELL_BG_PALETTE | CELL_BG_ALPHA_MASK);
+}
+
+// Extract those elements of the background channel which may be freely swapped
+// with the foreground channel (alpha and coloring info).
+static inline uint32_t
+cell_bchannel_common(const nccell* cl){
+  return channel_common(cell_bchannel(cl));
+}
+
+// Extract the 32-bit foreground channel from a cell.
+static inline uint32_t
+cell_fchannel(const nccell* cl){
+  return channels_fchannel(cl->channels);
+}
+
+// Extract those elements of the foreground channel which may be freely swapped
+// with the background channel (alpha and coloring info).
+static inline uint32_t
+cell_fchannel_common(const nccell* cl){
+  return channel_common(cell_fchannel(cl));
+}
+
+// Set the 32-bit background channel of an nccell.
+static inline uint64_t
+cell_set_bchannel(nccell* cl, uint32_t channel){
+  return channels_set_bchannel(&cl->channels, channel);
+}
+
+// Set the 32-bit foreground channel of an nccell.
+static inline uint64_t
+cell_set_fchannel(nccell* cl, uint32_t channel){
+  return channels_set_fchannel(&cl->channels, channel);
+}
+
 // Returns the result of blending two channels. 'blends' indicates how heavily
 // 'c1' ought be weighed. If 'blends' is 0, 'c1' will be entirely replaced by
 // 'c2'. If 'c1' is otherwise the default color, 'c1' will not be touched,
@@ -1044,6 +1166,8 @@ int ncinputlayer_init(ncinputlayer* nilayer, FILE* infp);
 // FIXME absorb into ncinputlayer_init()
 int cbreak_mode(int ttyfd, const struct termios* tpreserved);
 
+int set_fd_nonblocking(int fd, unsigned state, unsigned* oldstate);
+
 // Given the four channels arguments, verify that:
 //
 // - if any is default foreground, all are default foreground
@@ -1061,6 +1185,46 @@ int drop_signals(void* nc);
 
 void ncvisual_printbanner(const notcurses* nc);
 
+// alpha comes to us 0--255, but we have only 3 alpha values to map them to.
+// settled on experimentally.
+static inline bool
+rgba_trans_p(unsigned alpha){
+  if(alpha < 192){
+    return true;
+  }
+  return false;
+}
+
+static inline uint64_t
+ncdirect_channels(const ncdirect* nc){
+  return nc->channels;
+}
+
+static inline bool
+ncdirect_fg_default_p(const struct ncdirect* nc){
+  return channels_fg_default_p(ncdirect_channels(nc));
+}
+
+static inline bool
+ncdirect_bg_default_p(const struct ncdirect* nc){
+  return channels_bg_default_p(ncdirect_channels(nc));
+}
+
+int sixel_blit(ncplane* nc, int placey, int placex, int linesize,
+               const void* data, int begy, int begx,
+               int leny, int lenx, unsigned cellpixx);
+
+int term_fg_rgb8(bool RGBflag, const char* setaf, int colors, FILE* out,
+                 unsigned r, unsigned g, unsigned b);
+
+static inline int
+rgba_blit_dispatch(ncplane* nc, const struct blitset* bset, int placey,
+                   int placex, int linesize, const void* data, int begy,
+                   int begx, int leny, int lenx, bool blendcolors){
+  return bset->blit(nc, placey, placex, linesize, data, begy, begx,
+                    leny, lenx, blendcolors);
+}
+
 typedef struct ncvisual_implementation {
   int (*visual_init)(int loglevel);
   void (*visual_printbanner)(const struct notcurses* nc);
