@@ -180,11 +180,19 @@ void ncplane_dim_yx(const ncplane* n, int* rows, int* cols){
 
 // anyone calling this needs ensure the ncplane's framebuffer is updated
 // to reflect changes in geometry. also called at startup for standard plane.
-int update_term_dimensions(int fd, int* rows, int* cols){
+int update_term_dimensions(int fd, int* rows, int* cols, tinfo* tcache){
   // if we're not a real tty, we presumably haven't changed geometry, return
   if(fd < 0){
-    *rows = DEFAULT_ROWS;
-    *cols = DEFAULT_COLS;
+    if(rows){
+      *rows = DEFAULT_ROWS;
+    }
+    if(cols){
+      *cols = DEFAULT_COLS;
+    }
+    if(tcache){
+      tcache->cellpixy = 0;
+      tcache->cellpixx = 0;
+    }
     return 0;
   }
   struct winsize ws;
@@ -204,6 +212,10 @@ int update_term_dimensions(int fd, int* rows, int* cols){
   if(cols){
     *cols = ws.ws_col;
   }
+  if(tcache){
+    tcache->cellpixy = ws.ws_row ? ws.ws_ypixel / ws.ws_row : 0;
+    tcache->cellpixx = ws.ws_col ? ws.ws_xpixel / ws.ws_col : 0;
+  }
   return 0;
 }
 
@@ -695,18 +707,6 @@ int ncplane_genocide(ncplane *ncp){
   return ret;
 }
 
-static int
-make_nonblocking(int fd){
-  if(fd < 0){
-    return -1;
-  }
-  int flags = fcntl(fd, F_GETFL, 0);
-  if(flags < 0){
-    return -1;
-  }
-  return fcntl(fd, F_SETFL, flags | O_NONBLOCK);
-}
-
 static void
 reset_stats(ncstats* stats){
   uint64_t fbbytes = stats->fbbytes;
@@ -735,25 +735,120 @@ void notcurses_stats_reset(notcurses* nc, ncstats* stats){
   if(stats){
     memcpy(stats, &nc->stats, sizeof(*stats));
   }
+  // add the stats to the stashed stats, so that we can show true totals on
+  // shutdown in the closing banner
+  ncstats* stash = &nc->stashed_stats;
+  if(nc->stats.render_min_ns < stash->render_min_ns){
+    stash->render_min_ns = nc->stats.render_min_ns;
+  }
+  if(nc->stats.render_min_bytes < stash->render_min_bytes){
+    stash->render_min_bytes = nc->stats.render_min_bytes;
+  }
+  if(nc->stats.raster_min_ns < stash->raster_min_ns){
+    stash->raster_min_ns = nc->stats.raster_min_ns;
+  }
+  if(nc->stats.writeout_min_ns < stash->writeout_min_ns){
+    stash->writeout_min_ns = nc->stats.writeout_min_ns;
+  }
+  if(nc->stats.render_max_ns > stash->render_max_ns){
+    stash->render_max_ns = nc->stats.render_max_ns;
+  }
+  if(nc->stats.render_max_bytes > stash->render_max_bytes){
+    stash->render_max_bytes = nc->stats.render_max_bytes;
+  }
+  if(nc->stats.raster_max_ns > stash->raster_max_ns){
+    stash->raster_max_ns = nc->stats.raster_max_ns;
+  }
+  if(nc->stats.writeout_max_ns > stash->writeout_max_ns){
+    stash->writeout_max_ns = nc->stats.writeout_max_ns;
+  }
+  stash->writeout_ns += nc->stats.writeout_ns;
+  stash->raster_ns += nc->stats.raster_ns;
+  stash->render_ns += nc->stats.render_ns;
+  stash->render_bytes += nc->stats.render_bytes;
+  stash->failed_renders += nc->stats.failed_renders;
+  stash->failed_writeouts += nc->stats.failed_writeouts;
+  stash->renders += nc->stats.renders;
+  stash->writeouts += nc->stats.writeouts;
+  stash->cellelisions += nc->stats.cellelisions;
+  stash->cellemissions += nc->stats.cellemissions;
+  stash->fgelisions += nc->stats.fgelisions;
+  stash->fgemissions += nc->stats.fgemissions;
+  stash->bgelisions += nc->stats.bgelisions;
+  stash->bgemissions += nc->stats.bgemissions;
+  stash->defaultelisions += nc->stats.defaultelisions;
+  stash->defaultemissions += nc->stats.defaultemissions;
+  stash->refreshes = nc->stats.refreshes;
+  stash->fbbytes = nc->stats.fbbytes;
+  stash->planes = nc->stats.planes;
   reset_stats(&nc->stats);
   pthread_mutex_unlock(&nc->statlock);
 }
 
+// only invoked without suppress banners flag. prints various warnings based on
+// the environment / terminal definition.
+static void
+init_banner_warnings(const notcurses* nc, FILE* out){
+  // might be using stderr, so don't just reuse stdout decision
+  const bool tty = isatty(fileno(out));
+  if(tty){
+    term_fg_palindex(nc, out, nc->tcache.colors <= 88 ? 1 % nc->tcache.colors : 0xcb);
+  }
+  if(!nc->tcache.RGBflag){ // FIXME
+    fprintf(out, "\n Warning! Colors subject to https://github.com/dankamongmen/notcurses/issues/4");
+    fprintf(out, "\n  Specify a (correct) TrueColor TERM, or COLORTERM=24bit.\n");
+  }else{
+    if(!nc->tcache.CCCflag){
+      fprintf(out, "\n Warning! Advertised TrueColor but no 'ccc' flag\n");
+    }
+  }
+  if(!notcurses_canutf8(nc)){
+    fprintf(out, "\n Warning! Encoding is not UTF-8; output may be degraded.\n");
+  }
+  if(!nc->tcache.hpa){
+    fprintf(out, "\n Warning! No absolute horizontal placement.\n");
+  }
+  if(nc->tcache.sgr0){
+    if(tty){
+      term_emit(nc->tcache.sgr0, out, true);
+    }
+  }
+}
+
 // unless the suppress_banner flag was set, print some version information and
 // (if applicable) warnings to stdout. we are not yet on the alternate screen.
 static void
-init_banner(const notcurses* nc){
+init_banner(const notcurses* nc, const char* shortname_term){
   if(!nc->suppress_banner){
     char prefixbuf[BPREFIXSTRLEN + 1];
-    term_fg_palindex(nc, stdout, nc->tcache.colors <= 256 ? 50 % nc->tcache.colors : 0x20e080);
+    term_fg_palindex(nc, stdout, 50 % nc->tcache.colors);
     printf("\n notcurses %s by nick black et al", notcurses_version());
-    term_fg_palindex(nc, stdout, nc->tcache.colors <= 256 ? 12 % nc->tcache.colors : 0x2080e0);
-    printf("\n  %d rows %d cols (%sB) %zuB cells %d colors%s\n"
-           "  compiled with gcc-%s, %s-endian\n"
+    printf(" on %s", shortname_term ? shortname_term : "?");
+    term_fg_palindex(nc, stdout, 12 % nc->tcache.colors);
+    if(nc->tcache.cellpixy && nc->tcache.cellpixx){
+      printf("\n  %d rows (%dpx) %d cols (%dpx) (%sB) %d colors",
+             nc->stdplane->leny, nc->tcache.cellpixy,
+             nc->stdplane->lenx, nc->tcache.cellpixx,
+             bprefix(nc->stats.fbbytes, 1, prefixbuf, 0),
+             nc->tcache.colors);
+    }else{
+      printf("\n  %d rows %d cols (%sB) %d colors",
+             nc->stdplane->leny, nc->stdplane->lenx,
+             bprefix(nc->stats.fbbytes, 1, prefixbuf, 0),
+             nc->tcache.colors);
+    }
+    if(nc->tcache.RGBflag){
+      putc('+', stdout);
+      term_fg_rgb8(true, nc->tcache.setaf, nc->tcache.colors, stdout, 0xe0, 0x60, 0x60);
+      putc('R', stdout);
+      term_fg_rgb8(true, nc->tcache.setaf, nc->tcache.colors, stdout, 0x60, 0xe0, 0x60);
+      putc('G', stdout);
+      term_fg_rgb8(true, nc->tcache.setaf, nc->tcache.colors, stdout, 0x60, 0x60, 0xe0);
+      putc('B', stdout);
+      term_fg_palindex(nc, stdout, nc->tcache.colors <= 256 ? 12 % nc->tcache.colors : 0x2080e0);
+    }
+    printf("\n  compiled with gcc-%s, %s-endian %zuB cells\n"
            "  terminfo from %s\n",
-           nc->stdplane->leny, nc->stdplane->lenx,
-           bprefix(nc->stats.fbbytes, 1, prefixbuf, 0), sizeof(nccell),
-           nc->tcache.colors, nc->tcache.RGBflag ? "+RGB" : "",
            __VERSION__,
 #ifdef __BYTE_ORDER__
 #if __BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__
@@ -764,27 +859,10 @@ init_banner(const notcurses* nc){
 #else
 #error "No __BYTE_ORDER__ definition"
 #endif
-           , curses_version());
+           , sizeof(nccell), curses_version());
     ncvisual_printbanner(nc);
     fflush(stdout);
-    term_fg_palindex(nc, stderr, nc->tcache.colors <= 88 ? 1 % nc->tcache.colors : 0xcb);
-    if(!nc->tcache.RGBflag){ // FIXME
-      fprintf(stderr, "\n Warning! Colors subject to https://github.com/dankamongmen/notcurses/issues/4");
-      fprintf(stderr, "\n  Specify a (correct) TrueColor TERM, or COLORTERM=24bit.\n");
-    }else{
-      if(!nc->tcache.CCCflag){
-        fprintf(stderr, "\n Warning! Advertised TrueColor but no 'ccc' flag\n");
-      }
-    }
-    if(!notcurses_canutf8(nc)){
-      fprintf(stderr, "\n Warning! Encoding is not UTF-8; output may be degraded.\n");
-    }
-    if(!nc->tcache.hpa){
-      fprintf(stderr, "\n Warning! No absolute horizontal placement.\n");
-    }
-    if(nc->tcache.sgr0){
-      term_emit(nc->tcache.sgr0, stderr, true);
-    }
+    init_banner_warnings(nc, stderr);
   }
 }
 
@@ -894,6 +972,16 @@ recursive_lock_init(pthread_mutex_t *lock){
 #endif
 }
 
+int notcurses_check_pixel_support(notcurses* nc){
+  if(query_term(&nc->tcache, nc->ttyfd)){
+    return -1;
+  }
+  if(nc->tcache.sixel_supported){
+    return 1;
+  }
+  return 0;
+}
+
 // FIXME cut this up into a few distinct pieces, yearrrgh
 notcurses* notcurses_core_init(const notcurses_options* opts, FILE* outfp){
   notcurses_options defaultopts;
@@ -937,7 +1025,9 @@ notcurses* notcurses_core_init(const notcurses_options* opts, FILE* outfp){
   ret->margin_r = opts->margin_r;
   ret->cursory = ret->cursorx = -1;
   memset(&ret->stats, 0, sizeof(ret->stats));
+  memset(&ret->stashed_stats, 0, sizeof(ret->stashed_stats));
   reset_stats(&ret->stats);
+  reset_stats(&ret->stashed_stats);
   ret->ttyfp = outfp;
   ret->renderfp = opts->renderfp;
   memset(&ret->rstate, 0, sizeof(ret->rstate));
@@ -988,25 +1078,20 @@ notcurses* notcurses_core_init(const notcurses_options* opts, FILE* outfp){
     fprintf(stderr, "Terminfo error %d (see terminfo(3ncurses))\n", termerr);
     goto err;
   }
-  int dimy, dimx;
-  if(update_term_dimensions(ret->ttyfd, &dimy, &dimx)){
-    goto err;
-  }
-  ret->suppress_banner = opts->flags & NCOPTION_SUPPRESS_BANNERS;
-  char* shortname_term = termname();
-  char* longname_term = longname();
-  if(!ret->suppress_banner){
-    fprintf(stderr, "Term: %dx%d %s (%s)\n", dimy, dimx,
-            shortname_term ? shortname_term : "?",
-            longname_term ? longname_term : "?");
-  }
+  const char* shortname_term = termname();
+// const char* longname_term = longname();
   if(interrogate_terminfo(&ret->tcache, shortname_term, utf8)){
     goto err;
   }
+  int dimy, dimx;
+  if(update_term_dimensions(ret->ttyfd, &dimy, &dimx, &ret->tcache)){
+    goto err;
+  }
+  ret->suppress_banner = opts->flags & NCOPTION_SUPPRESS_BANNERS;
   if(ncinputlayer_init(&ret->input, stdin)){
     goto err;
   }
-  if(make_nonblocking(ret->input.ttyinfd)){
+  if(set_fd_nonblocking(ret->input.ttyinfd, 1, &ret->stdio_blocking_save)){
     goto err;
   }
   // Neither of these is supported on e.g. the "linux" virtual console.
@@ -1037,7 +1122,7 @@ notcurses* notcurses_core_init(const notcurses_options* opts, FILE* outfp){
     goto err;
   }
   ret->rstate.x = ret->rstate.y = -1;
-  init_banner(ret);
+  init_banner(ret, shortname_term);
   // flush on the switch to alternate screen, lest initial output be swept away
   if(ret->ttyfd >= 0){
     if(ret->tcache.smcup){
@@ -1110,6 +1195,7 @@ int notcurses_stop(notcurses* nc){
   int ret = 0;
   if(nc){
     ret |= notcurses_stop_minimal(nc);
+    ret |= set_fd_nonblocking(nc->input.ttyinfd, nc->stdio_blocking_save, NULL);
     if(nc->stdplane){
       notcurses_drop_planes(nc);
       free_plane(nc->stdplane);
@@ -1120,8 +1206,11 @@ int notcurses_stop(notcurses* nc){
     // if we were not using the alternate screen, our cursor's wherever we last
     // wrote. move it to the bottom left of the screen.
     if(!nc->tcache.smcup){
+      // FIXME combine into a single cup (heh)?
       tty_emit(tiparm(nc->tcache.hpa, 0), nc->ttyfd);
-      tty_emit(tiparm(nc->tcache.vpa, nc->lfdimy + nc->margin_t - 1), nc->ttyfd);
+      if(nc->lfdimy){
+        tty_emit(tiparm(nc->tcache.vpa, nc->lfdimy + nc->margin_t - 1), nc->ttyfd);
+      }
     }
     if(nc->ttyfd >= 0){
       ret |= close(nc->ttyfd);
@@ -1130,71 +1219,75 @@ int notcurses_stop(notcurses* nc){
     free(nc->lastframe);
     free(nc->rstate.mstream);
     input_free_esctrie(&nc->input.inputescapes);
+    // get any current stats loaded into stash_stats
+    notcurses_stats_reset(nc, NULL);
     if(!nc->suppress_banner){
-      if(nc->stats.renders){
+      const ncstats *stats = &nc->stashed_stats;
+      if(stats->renders){
         char totalbuf[BPREFIXSTRLEN + 1];
         char minbuf[BPREFIXSTRLEN + 1];
         char maxbuf[BPREFIXSTRLEN + 1];
         char avgbuf[BPREFIXSTRLEN + 1];
-        qprefix(nc->stats.render_ns, NANOSECS_IN_SEC, totalbuf, 0);
-        qprefix(nc->stats.render_min_ns, NANOSECS_IN_SEC, minbuf, 0);
-        qprefix(nc->stats.render_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
-        qprefix(nc->stats.render_ns / nc->stats.renders, NANOSECS_IN_SEC, avgbuf, 0);
+        qprefix(stats->render_ns, NANOSECS_IN_SEC, totalbuf, 0);
+        qprefix(stats->render_min_ns, NANOSECS_IN_SEC, minbuf, 0);
+        qprefix(stats->render_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
+        qprefix(stats->render_ns / stats->renders, NANOSECS_IN_SEC, avgbuf, 0);
         fprintf(stderr, "\n%ju render%s, %ss (%ss min, %ss avg, %ss max)\n",
-                nc->stats.renders, nc->stats.renders == 1 ? "" : "s",
+                stats->renders, stats->renders == 1 ? "" : "s",
                 totalbuf, minbuf, avgbuf, maxbuf);
-        qprefix(nc->stats.raster_ns, NANOSECS_IN_SEC, totalbuf, 0);
-        qprefix(nc->stats.raster_min_ns, NANOSECS_IN_SEC, minbuf, 0);
-        qprefix(nc->stats.raster_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
-        qprefix(nc->stats.raster_ns / nc->stats.writeouts, NANOSECS_IN_SEC, avgbuf, 0);
+        qprefix(stats->raster_ns, NANOSECS_IN_SEC, totalbuf, 0);
+        qprefix(stats->raster_min_ns, NANOSECS_IN_SEC, minbuf, 0);
+        qprefix(stats->raster_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
+        qprefix(stats->raster_ns / stats->writeouts, NANOSECS_IN_SEC, avgbuf, 0);
         fprintf(stderr, "%ju raster%s, %ss (%ss min, %ss avg, %ss max)\n",
-                nc->stats.writeouts, nc->stats.writeouts == 1 ? "" : "s",
+                stats->writeouts, stats->writeouts == 1 ? "" : "s",
                 totalbuf, minbuf, avgbuf, maxbuf);
-        qprefix(nc->stats.writeout_ns, NANOSECS_IN_SEC, totalbuf, 0);
-        qprefix(nc->stats.writeout_min_ns, NANOSECS_IN_SEC, minbuf, 0);
-        qprefix(nc->stats.writeout_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
-        qprefix(nc->stats.writeouts ? nc->stats.writeout_ns / nc->stats.writeouts : 0,
+        qprefix(stats->writeout_ns, NANOSECS_IN_SEC, totalbuf, 0);
+        qprefix(stats->writeout_min_ns, NANOSECS_IN_SEC, minbuf, 0);
+        qprefix(stats->writeout_max_ns, NANOSECS_IN_SEC, maxbuf, 0);
+        qprefix(stats->writeouts ? stats->writeout_ns / stats->writeouts : 0,
                 NANOSECS_IN_SEC, avgbuf, 0);
         fprintf(stderr, "%ju write%s, %ss (%ss min, %ss avg, %ss max)\n",
-                nc->stats.writeouts, nc->stats.writeouts == 1 ? "" : "s",
+                stats->writeouts, stats->writeouts == 1 ? "" : "s",
                 totalbuf, minbuf, avgbuf, maxbuf);
-        bprefix(nc->stats.render_bytes, 1, totalbuf, 1),
-        bprefix(nc->stats.render_min_bytes, 1, minbuf, 1),
-        bprefix(nc->stats.renders ? nc->stats.render_bytes / nc->stats.renders : 0, 1, avgbuf, 1);
-        bprefix(nc->stats.render_max_bytes, 1, maxbuf, 1),
+        bprefix(stats->render_bytes, 1, totalbuf, 1),
+        bprefix(stats->render_min_bytes, 1, minbuf, 1),
+        bprefix(stats->renders ? stats->render_bytes / stats->renders : 0, 1, avgbuf, 1);
+        bprefix(stats->render_max_bytes, 1, maxbuf, 1),
         fprintf(stderr, "%sB (%sB min, %sB avg, %sB max)\n",
                 totalbuf, minbuf, avgbuf, maxbuf);
       }
-      if(nc->stats.renders || nc->stats.failed_renders){
+      if(stats->renders || stats->failed_renders){
         fprintf(stderr, "%ju failed render%s, %ju failed write%s, %ju refresh%s\n",
-                nc->stats.failed_renders,
-                nc->stats.failed_renders == 1 ? "" : "s",
-                nc->stats.failed_writeouts,
-                nc->stats.failed_writeouts == 1 ? "" : "s",
-                nc->stats.refreshes,
-                nc->stats.refreshes == 1 ? "" : "es");
+                stats->failed_renders,
+                stats->failed_renders == 1 ? "" : "s",
+                stats->failed_writeouts,
+                stats->failed_writeouts == 1 ? "" : "s",
+                stats->refreshes,
+                stats->refreshes == 1 ? "" : "es");
         fprintf(stderr, "RGB emits:elides: def %ju:%ju fg %ju:%ju bg %ju:%ju\n",
-                nc->stats.defaultemissions,
-                nc->stats.defaultelisions,
-                nc->stats.fgemissions,
-                nc->stats.fgelisions,
-                nc->stats.bgemissions,
-                nc->stats.bgelisions);
+                stats->defaultemissions,
+                stats->defaultelisions,
+                stats->fgemissions,
+                stats->fgelisions,
+                stats->bgemissions,
+                stats->bgelisions);
         fprintf(stderr, "Cell emits:elides: %ju/%ju (%.2f%%) %.2f%% %.2f%% %.2f%%\n",
-                nc->stats.cellemissions, nc->stats.cellelisions,
-                (nc->stats.cellemissions + nc->stats.cellelisions) == 0 ? 0 :
-                (nc->stats.cellelisions * 100.0) / (nc->stats.cellemissions + nc->stats.cellelisions),
-                (nc->stats.defaultemissions + nc->stats.defaultelisions) == 0 ? 0 :
-                (nc->stats.defaultelisions * 100.0) / (nc->stats.defaultemissions + nc->stats.defaultelisions),
-                (nc->stats.fgemissions + nc->stats.fgelisions) == 0 ? 0 :
-                (nc->stats.fgelisions * 100.0) / (nc->stats.fgemissions + nc->stats.fgelisions),
-                (nc->stats.bgemissions + nc->stats.bgelisions) == 0 ? 0 :
-                (nc->stats.bgelisions * 100.0) / (nc->stats.bgemissions + nc->stats.bgelisions));
+                stats->cellemissions, stats->cellelisions,
+                (stats->cellemissions + stats->cellelisions) == 0 ? 0 :
+                (stats->cellelisions * 100.0) / (stats->cellemissions + stats->cellelisions),
+                (stats->defaultemissions + stats->defaultelisions) == 0 ? 0 :
+                (stats->defaultelisions * 100.0) / (stats->defaultemissions + stats->defaultelisions),
+                (stats->fgemissions + stats->fgelisions) == 0 ? 0 :
+                (stats->fgelisions * 100.0) / (stats->fgemissions + stats->fgelisions),
+                (stats->bgemissions + stats->bgelisions) == 0 ? 0 :
+                (stats->bgelisions * 100.0) / (stats->bgemissions + stats->bgelisions));
       }
     }
     del_curterm(cur_term);
     ret |= pthread_mutex_destroy(&nc->statlock);
     ret |= pthread_mutex_destroy(&nc->pilelock);
+    free_terminfo_cache(&nc->tcache);
     free(nc);
   }
   return ret;
@@ -2052,8 +2145,8 @@ bool notcurses_canchangecolor(const notcurses* nc){
   return true;
 }
 
-bool notcurses_cansixel(const notcurses* nc){
-  return nc->tcache.libsixel;
+bool notcurses_canpixel(const notcurses* nc){
+  return nc->tcache.sixel_supported;
 }
 
 palette256* palette256_new(notcurses* nc){
@@ -2204,10 +2297,12 @@ ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
   if(n->blist){
     if(n->boundto == n){ // children become new root planes
       ncplane* lastlink;
-      for(ncplane* child = n->blist ; child ; child = child->bnext){
+      ncplane* child = n->blist;
+      do{
         child->boundto = child;
         lastlink = child;
-      } // n->blist != NULL -> lastlink != NULL
+        child = child->bnext;
+      }while(child); // n->blist != NULL -> lastlink != NULL
       if( (lastlink->bnext = ncplane_pile(n)->roots) ){
         lastlink->bnext->bprev = &lastlink->bnext;
       }
@@ -2215,10 +2310,12 @@ ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
       ncplane_pile(n)->roots = n->blist;
     }else{ // children are rebound to current parent
       ncplane* lastlink;
-      for(ncplane* child = n->blist ; child ; child = child->bnext){
+      ncplane* child = n->blist;
+      do{
         child->boundto = n->boundto;
         lastlink = child;
-      } // n->blist != NULL -> lastlink != NULL
+        child = child->bnext;
+      }while(child); // n->blist != NULL -> lastlink != NULL
       if( (lastlink->bnext = n->boundto->blist) ){
         lastlink->bnext->bprev = &lastlink->bnext;
       }
