@@ -23,7 +23,7 @@ notcurses_resize_internal(ncplane* pp, int* restrict rows, int* restrict cols){
   int oldcols = pile->dimx;
   *rows = oldrows;
   *cols = oldcols;
-  if(update_term_dimensions(n->ttyfd, rows, cols)){
+  if(update_term_dimensions(n->ttyfd, rows, cols, &n->tcache)){
     return -1;
   }
   *rows -= n->margin_t + n->margin_b;
@@ -79,7 +79,7 @@ blocking_write(int fd, const char* buf, size_t buflen){
   while(written < buflen){
     ssize_t w = write(fd, buf + written, buflen - written);
     if(w < 0){
-      if(errno != EAGAIN && errno != EWOULDBLOCK){
+      if(errno != EAGAIN && errno != EWOULDBLOCK && errno != EINTR){
         return -1;
       }
     }else{
@@ -401,6 +401,7 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
             targc->stylemask = vis->stylemask;
             targc->width = vis->width;
           }
+          cell_set_pixels(targc, cell_pixels_p(vis));
           crender->p = p;
         }else if(cell_wide_right_p(vis)){
           crender->p = p;
@@ -415,11 +416,11 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
 // we need CELL_ALPHA_TRANSPARENT
 static inline void
 init_rvec(struct crender* rvec, int totalcells){
-  memset(rvec, 0, sizeof(*rvec) * totalcells);
+  struct crender c = {};
+  cell_set_fg_alpha(&c.c, CELL_ALPHA_TRANSPARENT);
+  cell_set_bg_alpha(&c.c, CELL_ALPHA_TRANSPARENT);
   for(int t = 0 ; t < totalcells ; ++t){
-    struct crender* c = &rvec[t];
-    cell_set_fg_alpha(&c->c, CELL_ALPHA_TRANSPARENT);
-    cell_set_bg_alpha(&c->c, CELL_ALPHA_TRANSPARENT);
+    memcpy(&rvec[t], &c, sizeof(c));
   }
 }
 
@@ -627,25 +628,23 @@ int term_setstyle(FILE* out, unsigned cur, unsigned targ, unsigned stylebit,
 
 // write any escape sequences necessary to set the desired style
 static inline int
-term_setstyles(FILE* out, uint32_t* curattr, const nccell* c, bool* normalized,
-               const char* sgr0, const char* sgr, const char* italics,
-               const char* italoff, const char* struck, const char* struckoff){
-  *normalized = false;
+term_setstyles(FILE* out, notcurses* nc, const nccell* c){
+  bool normalized = false;
   uint32_t cellattr = cell_styles(c);
-  if(cellattr == *curattr){
+  if(cellattr == nc->rstate.curattr){
     return 0; // happy agreement, change nothing
   }
   int ret = 0;
   // if only italics changed, don't emit any sgr escapes. xor of current and
   // target ought have all 0s in the lower 8 bits if only italics changed.
-  if((cellattr ^ *curattr) & 0xfful){
-    *normalized = true; // FIXME this is pretty conservative
+  if((cellattr ^ nc->rstate.curattr) & 0xfful){
+    normalized = true; // FIXME this is pretty conservative
     // if everything's 0, emit the shorter sgr0
-    if(sgr0 && ((cellattr & NCSTYLE_MASK) == 0)){
-      if(term_emit(sgr0, out, false) < 0){
+    if(nc->tcache.sgr0 && ((cellattr & NCSTYLE_MASK) == 0)){
+      if(term_emit(nc->tcache.sgr0, out, false) < 0){
         ret = -1;
       }
-    }else if(term_emit(tiparm(sgr, cellattr & NCSTYLE_STANDOUT,
+    }else if(term_emit(tiparm(nc->tcache.sgr, cellattr & NCSTYLE_STANDOUT,
                               cellattr & NCSTYLE_UNDERLINE,
                               cellattr & NCSTYLE_REVERSE,
                               cellattr & NCSTYLE_BLINK,
@@ -657,11 +656,21 @@ term_setstyles(FILE* out, uint32_t* curattr, const nccell* c, bool* normalized,
       ret = -1;
     }
     // sgr will blow away italics/struck if they were set beforehand
-    *curattr &= !(NCSTYLE_ITALIC | NCSTYLE_STRUCK);
+    nc->rstate.curattr &= !(NCSTYLE_ITALIC | NCSTYLE_STRUCK);
+  }
+  ret |= term_setstyle(out, nc->rstate.curattr, cellattr, NCSTYLE_ITALIC,
+                       nc->tcache.italics, nc->tcache.italoff);
+  ret |= term_setstyle(out, nc->rstate.curattr, cellattr, NCSTYLE_STRUCK,
+                       nc->tcache.struck, nc->tcache.struckoff);
+  nc->rstate.curattr = cellattr;
+  if(normalized){
+    nc->rstate.fgdefelidable = true;
+    nc->rstate.bgdefelidable = true;
+    nc->rstate.bgelidable = false;
+    nc->rstate.fgelidable = false;
+    nc->rstate.bgpalelidable = false;
+    nc->rstate.fgpalelidable = false;
   }
-  ret |= term_setstyle(out, *curattr, cellattr, NCSTYLE_ITALIC, italics, italoff);
-  ret |= term_setstyle(out, *curattr, cellattr, NCSTYLE_STRUCK, struck, struckoff);
-  *curattr = cellattr;
   return ret;
 }
 
@@ -765,9 +774,8 @@ term_bg_rgb8(bool RGBflag, const char* setab, int colors, FILE* out,
   return 0;
 }
 
-static inline int
-term_fg_rgb8(bool RGBflag, const char* setaf, int colors, FILE* out,
-             unsigned r, unsigned g, unsigned b){
+int term_fg_rgb8(bool RGBflag, const char* setaf, int colors, FILE* out,
+                 unsigned r, unsigned g, unsigned b){
   // We typically want to use tputs() and tiperm() to acquire and write the
   // escapes, as these take into account terminal-specific delays, padding,
   // etc. For the case of DirectColor, there is no suitable terminfo entry, but
@@ -818,13 +826,14 @@ update_palette(notcurses* nc, FILE* out){
 // our understanding of our horizontal location is faulty.
 // FIXME fall back to synthesized moves in the absence of capabilities (i.e.
 // textronix lacks cup; fake it with horiz+vert moves)
+// if hardposupdate is non-zero, we always perform a cup
 static inline int
-goto_location(notcurses* nc, FILE* out, int y, int x){
+goto_location(notcurses* nc, FILE* out, int y, int x, unsigned hardposupdate){
   int ret = 0;
   // if we don't have hpa, force a cup even if we're only 1 char away. the only
   // terminal i know supporting cup sans hpa is vt100, and vt100 can suck it.
   // you can't use cuf for backwards moves anyway; again, vt100 can suck it.
-  if(nc->rstate.y == y && nc->tcache.hpa){ // only need move x
+  if(nc->rstate.y == y && nc->tcache.hpa && !hardposupdate){ // only need move x
     if(nc->rstate.x == x){ // needn't move shit
       return 0;
     }
@@ -907,6 +916,7 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
   // we explicitly move the cursor at the beginning of each output line, so no
   // need to home it expliticly.
   update_palette(nc, out);
+  bool hardposupdate = false;
 //fprintf(stderr, "pile %p ymax: %d xmax: %d\n", p, p->dimy + nc->stdplane->absy, p->dimx + nc->stdplane->absx);
   for(y = nc->stdplane->absy ; y < p->dimy + nc->stdplane->absy ; ++y){
     const int innery = y - nc->stdplane->absy;
@@ -924,113 +934,107 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
         }
       }else{
         ++nc->stats.cellemissions;
-        if(goto_location(nc, out, y, x)){
+        if(goto_location(nc, out, y, x, hardposupdate)){
           return -1;
         }
-        // set the style. this can change the color back to the default; if it
-        // does, we need update our elision possibilities.
-        bool normalized;
-        if(term_setstyles(out, &nc->rstate.curattr, srccell, &normalized,
-                          nc->tcache.sgr0, nc->tcache.sgr,
-                          nc->tcache.italics, nc->tcache.italoff,
-                          nc->tcache.struck, nc->tcache.struckoff)){
-          return -1;
-        }
-        if(normalized){
-          nc->rstate.fgdefelidable = true;
-          nc->rstate.bgdefelidable = true;
-          nc->rstate.bgelidable = false;
-          nc->rstate.fgelidable = false;
-          nc->rstate.bgpalelidable = false;
-          nc->rstate.fgpalelidable = false;
-        }
-        // if our cell has a default foreground *or* background, we can elide
-        // the default set iff one of:
-        //  * we are a partial glyph, and the previous was default on both, or
-        //  * we are a no-foreground glyph, and the previous was default background, or
-        //  * we are a no-background glyph, and the previous was default foreground
-        bool nobackground = cell_nobackground_p(srccell);
-        if((cell_fg_default_p(srccell)) || (!nobackground && cell_bg_default_p(srccell))){
-          if(raster_defaults(nc, cell_fg_default_p(srccell),
-                             !nobackground && cell_bg_default_p(srccell), out)){
+        hardposupdate = false;
+        if(!cell_pixels_p(srccell)){
+          // set the style. this can change the color back to the default; if it
+          // does, we need update our elision possibilities.
+          if(term_setstyles(out, nc, srccell)){
             return -1;
           }
-        }
-        // if our cell has a non-default foreground, we can elide the
-        // non-default foreground set iff either:
-        //  * the previous was non-default, and matches what we have now, or
-        //  * we are a no-foreground glyph (iswspace() is true)
-        if(cell_fg_palindex_p(srccell)){ // palette-indexed foreground
-          palfg = cell_fg_palindex(srccell);
-          // we overload lastr for the palette index; both are 8 bits
-          if(nc->rstate.fgpalelidable && nc->rstate.lastr == palfg){
-            ++nc->stats.fgelisions;
-          }else{
-            if(term_fg_palindex(nc, out, palfg)){
+          // if our cell has a default foreground *or* background, we can elide
+          // the default set iff one of:
+          //  * we are a partial glyph, and the previous was default on both, or
+          //  * we are a no-foreground glyph, and the previous was default background, or
+          //  * we are a no-background glyph, and the previous was default foreground
+          bool nobackground = cell_nobackground_p(srccell);
+          if((cell_fg_default_p(srccell)) || (!nobackground && cell_bg_default_p(srccell))){
+            if(raster_defaults(nc, cell_fg_default_p(srccell),
+                              !nobackground && cell_bg_default_p(srccell), out)){
               return -1;
             }
-            ++nc->stats.fgemissions;
-            nc->rstate.fgpalelidable = true;
           }
-          nc->rstate.lastr = palfg;
-          nc->rstate.fgdefelidable = false;
-          nc->rstate.fgelidable = false;
-        }else if(!cell_fg_default_p(srccell)){ // rgb foreground
-          cell_fg_rgb8(srccell, &r, &g, &b);
-          if(nc->rstate.fgelidable && nc->rstate.lastr == r && nc->rstate.lastg == g && nc->rstate.lastb == b){
-            ++nc->stats.fgelisions;
-          }else{
-            if(term_fg_rgb8(nc->tcache.RGBflag, nc->tcache.setaf, nc->tcache.colors, out, r, g, b)){
-              return -1;
+          // if our cell has a non-default foreground, we can elide the
+          // non-default foreground set iff either:
+          //  * the previous was non-default, and matches what we have now, or
+          //  * we are a no-foreground glyph (iswspace() is true)
+          if(cell_fg_palindex_p(srccell)){ // palette-indexed foreground
+            palfg = cell_fg_palindex(srccell);
+            // we overload lastr for the palette index; both are 8 bits
+            if(nc->rstate.fgpalelidable && nc->rstate.lastr == palfg){
+              ++nc->stats.fgelisions;
+            }else{
+              if(term_fg_palindex(nc, out, palfg)){
+                return -1;
+              }
+              ++nc->stats.fgemissions;
+              nc->rstate.fgpalelidable = true;
             }
-            ++nc->stats.fgemissions;
-            nc->rstate.fgelidable = true;
+            nc->rstate.lastr = palfg;
+            nc->rstate.fgdefelidable = false;
+            nc->rstate.fgelidable = false;
+          }else if(!cell_fg_default_p(srccell)){ // rgb foreground
+            cell_fg_rgb8(srccell, &r, &g, &b);
+            if(nc->rstate.fgelidable && nc->rstate.lastr == r && nc->rstate.lastg == g && nc->rstate.lastb == b){
+              ++nc->stats.fgelisions;
+            }else{
+              if(term_fg_rgb8(nc->tcache.RGBflag, nc->tcache.setaf, nc->tcache.colors, out, r, g, b)){
+                return -1;
+              }
+              ++nc->stats.fgemissions;
+              nc->rstate.fgelidable = true;
+            }
+            nc->rstate.lastr = r; nc->rstate.lastg = g; nc->rstate.lastb = b;
+            nc->rstate.fgdefelidable = false;
+            nc->rstate.fgpalelidable = false;
           }
-          nc->rstate.lastr = r; nc->rstate.lastg = g; nc->rstate.lastb = b;
-          nc->rstate.fgdefelidable = false;
-          nc->rstate.fgpalelidable = false;
-        }
-        // if our cell has a non-default background, we can elide the
-        // non-default background set iff either:
-        //  * we do not use the background, because the cell is all-foreground,
-        //  * the previous was non-default, and matches what we have now, or
-        if(nobackground){
-          ++nc->stats.bgelisions;
-        }else if(cell_bg_palindex_p(srccell)){ // palette-indexed background
-          palbg = cell_bg_palindex(srccell);
-          if(nc->rstate.bgpalelidable && nc->rstate.lastbr == palbg){
+          // if our cell has a non-default background, we can elide the
+          // non-default background set iff either:
+          //  * we do not use the background, because the cell is all-foreground,
+          //  * the previous was non-default, and matches what we have now, or
+          if(nobackground){
             ++nc->stats.bgelisions;
-          }else{
-            if(term_bg_palindex(nc, out, palbg)){
-              return -1;
+          }else if(cell_bg_palindex_p(srccell)){ // palette-indexed background
+            palbg = cell_bg_palindex(srccell);
+            if(nc->rstate.bgpalelidable && nc->rstate.lastbr == palbg){
+              ++nc->stats.bgelisions;
+            }else{
+              if(term_bg_palindex(nc, out, palbg)){
+                return -1;
+              }
+              ++nc->stats.bgemissions;
+              nc->rstate.bgpalelidable = true;
             }
-            ++nc->stats.bgemissions;
-            nc->rstate.bgpalelidable = true;
-          }
-          nc->rstate.lastr = palbg;
-          nc->rstate.bgdefelidable = false;
-          nc->rstate.bgelidable = false;
-        }else if(!cell_bg_default_p(srccell)){ // rgb background
-          cell_bg_rgb8(srccell, &br, &bg, &bb);
-          if(nc->rstate.bgelidable && nc->rstate.lastbr == br && nc->rstate.lastbg == bg && nc->rstate.lastbb == bb){
-            ++nc->stats.bgelisions;
-          }else{
-            if(term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab,
-                            nc->tcache.colors, out, br, bg, bb,
-                            nc->tcache.bg_collides_default)){
-              return -1;
+            nc->rstate.lastr = palbg;
+            nc->rstate.bgdefelidable = false;
+            nc->rstate.bgelidable = false;
+          }else if(!cell_bg_default_p(srccell)){ // rgb background
+            cell_bg_rgb8(srccell, &br, &bg, &bb);
+            if(nc->rstate.bgelidable && nc->rstate.lastbr == br && nc->rstate.lastbg == bg && nc->rstate.lastbb == bb){
+              ++nc->stats.bgelisions;
+            }else{
+              if(term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab,
+                              nc->tcache.colors, out, br, bg, bb,
+                              nc->tcache.bg_collides_default)){
+                return -1;
+              }
+              ++nc->stats.bgemissions;
+              nc->rstate.bgelidable = true;
             }
-            ++nc->stats.bgemissions;
-            nc->rstate.bgelidable = true;
+            nc->rstate.lastbr = br; nc->rstate.lastbg = bg; nc->rstate.lastbb = bb;
+            nc->rstate.bgdefelidable = false;
+            nc->rstate.bgpalelidable = false;
           }
-          nc->rstate.lastbr = br; nc->rstate.lastbg = bg; nc->rstate.lastbb = bb;
-          nc->rstate.bgdefelidable = false;
-          nc->rstate.bgpalelidable = false;
+        }else{
+          hardposupdate = true;
         }
 //fprintf(stderr, "RAST %08x [%s] to %d/%d cols: %u %016lx\n", srccell->gcluster, pool_extended_gcluster(&nc->pool, srccell), y, x, srccell->width, srccell->channels);
         if(term_putc(out, &nc->pool, srccell)){
           return -1;
         }
+        // if we just emitted a sixel, always force a hard cursor relocation
         ++nc->rstate.x;
         if(srccell->width >= 2){
           x += srccell->width - 1;
@@ -1321,6 +1325,10 @@ int ncdirect_set_bg_rgb(ncdirect* nc, unsigned rgb){
   if(rgb > 0xffffffu){
     return -1;
   }
+  // FIXME need verify we're not palette, either
+  if(!ncdirect_bg_default_p(nc) && channels_bg_rgb(nc->channels) == rgb){
+    return 0;
+  }
   if(term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab, nc->tcache.colors, nc->ttyfp,
                   (rgb & 0xff0000u) >> 16u, (rgb & 0xff00u) >> 8u, rgb & 0xffu,
                   nc->tcache.bg_collides_default)){
@@ -1334,6 +1342,10 @@ int ncdirect_set_fg_rgb(ncdirect* nc, unsigned rgb){
   if(rgb > 0xffffffu){
     return -1;
   }
+  // FIXME need verify we're not palette, either
+  if(!ncdirect_fg_default_p(nc) && channels_fg_rgb(nc->channels) == rgb){
+    return 0;
+  }
   if(term_fg_rgb8(nc->tcache.RGBflag, nc->tcache.setaf, nc->tcache.colors, nc->ttyfp,
                   (rgb & 0xff0000u) >> 16u, (rgb & 0xff00u) >> 8u, rgb & 0xffu)){
     return -1;
@@ -1359,7 +1371,7 @@ int notcurses_cursor_enable(notcurses* nc, int y, int x){
   if(nc->ttyfd < 0 || !nc->tcache.cnorm){
     return -1;
   }
-  if(goto_location(nc, nc->ttyfp, y + nc->stdplane->absy, x + nc->stdplane->absx)){
+  if(goto_location(nc, nc->ttyfp, y + nc->stdplane->absy, x + nc->stdplane->absx, 0)){
     return -1;
   }
   // if we were already positive, we're already visible, no need to write cnorm
