@@ -69,7 +69,7 @@ ncselector_body_width(const ncselector* n){
 static int
 ncselector_draw(ncselector* n){
   ncplane_erase(n->ncp);
-  cell transchar = CELL_TRIVIAL_INITIALIZER;
+  nccell transchar = CELL_TRIVIAL_INITIALIZER;
   cell_set_fg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
   cell_set_bg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
   // if we have a title, we'll draw a riser. the riser is two rows tall, and
@@ -145,7 +145,7 @@ ncselector_draw(ncselector* n){
   ++yoff;
   ncplane_cursor_move_yx(n->ncp, yoff, xoff + 1);
   for(int i = xoff + 1 ; i < dimx - 1 ; ++i){
-    cell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
+    nccell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
     ncplane_putc(n->ncp, &transc);
   }
   const int bodyoffset = dimx - bodywidth + 2;
@@ -169,7 +169,7 @@ ncselector_draw(ncselector* n){
     }
     ncplane_cursor_move_yx(n->ncp, yoff, xoff + 1);
     for(int i = xoff + 1 ; i < dimx - 1 ; ++i){
-      cell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
+      nccell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
       ncplane_putc(n->ncp, &transc);
     }
     n->ncp->channels = n->opchannels;
@@ -190,7 +190,7 @@ ncselector_draw(ncselector* n){
   // Bottom line of body (background and possibly down arrow)
   ncplane_cursor_move_yx(n->ncp, yoff, xoff + 1);
   for(int i = xoff + 1 ; i < dimx - 1 ; ++i){
-    cell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
+    nccell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
     ncplane_putc(n->ncp, &transc);
   }
   if(n->maxdisplay && n->maxdisplay < n->itemcount){
@@ -247,8 +247,9 @@ ncselector* ncselector_create(ncplane* n, const ncselector_options* opts){
   }
   ncselector* ns = malloc(sizeof(*ns));
   if(ns == NULL){
-    goto freeitems;
+    return NULL;
   }
+  memset(ns, 0, sizeof(*ns));
   if(opts->defidx && opts->defidx >= itemcount){
     goto freeitems;
   }
@@ -562,7 +563,7 @@ ncmultiselector_body_width(const ncmultiselector* n){
 static int
 ncmultiselector_draw(ncmultiselector* n){
   ncplane_erase(n->ncp);
-  cell transchar = CELL_TRIVIAL_INITIALIZER;
+  nccell transchar = CELL_TRIVIAL_INITIALIZER;
   cell_set_fg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
   cell_set_bg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
   // if we have a title, we'll draw a riser. the riser is two rows tall, and
@@ -625,7 +626,7 @@ ncmultiselector_draw(ncmultiselector* n){
   ++yoff;
   ncplane_cursor_move_yx(n->ncp, yoff, xoff + 1);
   for(int i = xoff + 1 ; i < dimx - 1 ; ++i){
-    cell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
+    nccell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
     ncplane_putc(n->ncp, &transc);
   }
   const int bodyoffset = dimx - bodywidth + 2;
@@ -646,7 +647,7 @@ ncmultiselector_draw(ncmultiselector* n){
     }
     ncplane_cursor_move_yx(n->ncp, yoff, xoff + 1);
     for(int i = xoff + 1 ; i < dimx - 1 ; ++i){
-      cell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
+      nccell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
       ncplane_putc(n->ncp, &transc);
     }
     n->ncp->channels = n->descchannels;
@@ -676,7 +677,7 @@ ncmultiselector_draw(ncmultiselector* n){
   // Bottom line of body (background and possibly down arrow)
   ncplane_cursor_move_yx(n->ncp, yoff, xoff + 1);
   for(int i = xoff + 1 ; i < dimx - 1 ; ++i){
-    cell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
+    nccell transc = CELL_TRIVIAL_INITIALIZER; // fall back to base cell
     ncplane_putc(n->ncp, &transc);
   }
   if(n->maxdisplay && n->maxdisplay < n->itemcount){
@@ -842,6 +843,10 @@ ncmultiselector* ncmultiselector_create(ncplane* n, const ncmultiselector_option
     }
   }
   ncmultiselector* ns = malloc(sizeof(*ns));
+  if(ns == NULL){
+    return NULL;
+  }
+  memset(ns, 0, sizeof(*ns));
   ns->title = opts->title ? strdup(opts->title) : NULL;
   ns->titlecols = opts->title ? ncstrwidth(opts->title) : 0;
   ns->secondary = opts->secondary ? strdup(opts->secondary) : NULL;
