@@ -1,3 +1,4 @@
+#include <fcntl.h>
 #include <ncurses.h> // needed for some definitions, see terminfo(3ncurses)
 #include "internal.h"
 
@@ -71,6 +72,10 @@ apply_term_heuristics(tinfo* ti, const char* termname){
   return 0;
 }
 
+void free_terminfo_cache(tinfo* ti){
+  pthread_mutex_destroy(&ti->pixel_query);
+}
+
 // termname is just the TERM environment variable. some details are not
 // exposed via terminfo, and we must make heuristic decisions based on
 // the detected terminal type, yuck :/.
@@ -184,8 +189,89 @@ int interrogate_terminfo(tinfo* ti, const char* termname, unsigned utf8){
     ti->fgop = "\x1b[39m";
     ti->bgop = "\x1b[49m";
   }
+  pthread_mutex_init(&ti->pixel_query, NULL);
+  ti->pixel_query_done = false;
   if(apply_term_heuristics(ti, termname)){
     return -1;
   }
   return 0;
 }
+
+static int
+query_sixel(tinfo* ti, int fd){
+  if(writen(fd, "\033[c", 3) != 3){
+    return -1;
+  }
+  char in;
+  // perhaps the most lackadaisical response is that of st, which returns a
+  // bare ESC[?6c (note no semicolon).
+  enum {
+    WANT_CSI,
+    WANT_QMARK,
+    WANT_SEMI,
+    WANT_C,
+    DONE
+  } state = WANT_CSI;
+  while(read(fd, &in, 1) == 1){
+    switch(state){
+      case WANT_CSI:
+        if(in == NCKEY_ESC){
+          state = WANT_QMARK;
+        }
+        break;
+      case WANT_QMARK:
+        if(in == '?'){
+          state = WANT_SEMI;
+        }
+        break;
+      case WANT_SEMI:
+        if(in == ';'){
+          state = WANT_C;
+        }else if(in == 'c'){
+          state = DONE;
+        }
+        break;
+      case WANT_C:
+        if(in == 'c'){
+          state = DONE;
+        }else if(in == '4'){
+          if(!ti->sixel_supported){
+            ti->sixel_supported = true;
+          } // FIXME else warning?
+        }
+        break;
+      case DONE:
+      default:
+        break;
+    }
+    if(state == DONE){
+      break;
+    }
+  }
+  return 0;
+}
+
+// fd must be a real terminal. uses the query lock of |ti| to only act once.
+int query_term(tinfo* ti, int fd){
+  if(fd < 0){
+    return -1;
+  }
+  int flags = fcntl(fd, F_GETFL, 0);
+  if(flags < 0){
+    return -1;
+  }
+  int ret = 0;
+  pthread_mutex_lock(&ti->pixel_query);
+  if(!ti->pixel_query_done){
+    if(flags & O_NONBLOCK){
+      fcntl(fd, F_SETFL, flags & ~O_NONBLOCK);
+    }
+    ret = query_sixel(ti, fd);
+    ti->pixel_query_done = true;
+    if(flags & O_NONBLOCK){
+      fcntl(fd, F_SETFL, flags);
+    }
+  }
+  pthread_mutex_unlock(&ti->pixel_query);
+  return ret;
+}
