@@ -27,8 +27,8 @@ void usage(std::ostream& o, const char* name, int exitcode){
   o << " -L: loop frames\n";
   o << " -t seconds: delay t seconds after each file\n";
   o << " -l loglevel: integer between 0 and 9, goes to stderr'\n";
-  o << " -s scaletype: one of 'none', 'hires', 'scale', 'scalehi', or 'stretch'\n";
-  o << " -b blitter: 'ascii', 'halfblock', 'quadblitter', 'sexblitter', or 'braille'\n";
+  o << " -s scaling: one of 'none', 'hires', 'scale', 'scalehi', or 'stretch'\n";
+  o << " -b blitter: one of 'ascii', 'half', 'quad', 'sex', 'braille', or 'pixel'\n";
   o << " -m margins: margin, or 4 comma-separated margins\n";
   o << " -d mult: non-negative floating point scale for frame time" << std::endl;
   exit(exitcode);
@@ -66,7 +66,7 @@ auto perframe(struct ncvisual* ncv, struct ncvisual_options* vopts,
     marsh->blitter = ncvisual_media_defblitter(nc, vopts->scaling);
   }
   if(!marsh->quiet){
-    stdn->printf(0, NCAlign::Left, "frame %06d\u2026 (%s)", marsh->framecount,
+    stdn->printf(0, NCAlign::Left, "frame %06d (%s)", marsh->framecount,
                  notcurses_str_blitter(vopts->blitter));
   }
   char* subtitle = ncvisual_subtitle(ncv);
@@ -140,9 +140,18 @@ auto perframe(struct ncvisual* ncv, struct ncvisual_options* vopts,
     }
     if(keyp == NCKey::Resize){
       return 0;
+    }else if(keyp == 'L'){ // FIXME check for ctrl+l
+      nc.refresh(nullptr, nullptr);
+      continue;
     }else if(keyp >= '0' && keyp <= '8'){ // FIXME eliminate ctrl/alt
       marsh->blitter = static_cast<ncblitter_e>(keyp - '0');
       vopts->blitter = marsh->blitter;
+      if(vopts->blitter == NCBLIT_PIXEL){
+        notcurses_check_pixel_support(nc);
+        vopts->y = 1;
+      }else{
+        vopts->y = 0;
+      }
       continue;
     }else if(keyp == NCKey::Up){
       // FIXME
@@ -280,6 +289,9 @@ int direct_mode_player(int argc, char** argv, ncscale_e scalemode, ncblitter_e b
     return -1;
   }
   bool failed = false;
+  if(blitter == NCBLIT_PIXEL){
+    dm.check_pixel_support();
+  }
   {
     for(auto i = 0 ; i < argc ; ++i){
       try{
@@ -347,6 +359,12 @@ auto main(int argc, char** argv) -> int {
       vopts.n = *stdn;
       vopts.scaling = scalemode;
       vopts.blitter = blitter;
+      if(vopts.blitter == NCBLIT_PIXEL){
+        notcurses_check_pixel_support(nc);
+        vopts.y = 1;
+      }else{
+        vopts.y = 0;
+      }
       do{
         struct marshal marsh = {
           .subtitle_plane = nullptr,
@@ -372,6 +390,9 @@ auto main(int argc, char** argv) -> int {
                 break;
               }else if(ie == 'q'){
                 goto done;
+              }else if(ie == 'L'){
+                --i;
+                nc.refresh(nullptr, nullptr);
               }else if(ie >= '0' && ie <= '8'){
                 --i; // rerun same input with the new blitter
                 vopts.blitter = blitter = static_cast<ncblitter_e>(ie - '0');
