@@ -5,7 +5,7 @@ int main(void){
   struct notcurses_options opts = {
     .flags = NCOPTION_NO_ALTERNATE_SCREEN,
   };
-  struct notcurses* nc = notcurses_init(&opts, NULL);
+  struct notcurses* nc = notcurses_core_init(&opts, NULL);
   if(!nc){
     return EXIT_FAILURE;
   }
