@@ -7,7 +7,7 @@ int main(void){
   struct notcurses_options opts = {
     .flags = NCOPTION_INHIBIT_SETLOCALE,
   };
-  struct notcurses* nc = notcurses_init(&opts, NULL);
+  struct notcurses* nc = notcurses_core_init(&opts, NULL);
   if(nc == NULL){
     return EXIT_FAILURE;
   }
